@@ -46,31 +46,6 @@ use Time::HiRes qw( usleep );
 use constant SYNC => 0xff;
 use constant COMMAND_GAP => 100000; # In ms
 
-sub new
-{
-    my $class = shift;
-    my $id = shift;
-    my $self = ZoneMinder::Control->new( $id );
-    bless( $self, $class );
-    srand( time() );
-    return $self;
-}
-
-our $AUTOLOAD;
-
-sub AUTOLOAD
-{
-    my $self = shift;
-    my $class = ref($self) || croak( "$self not object" );
-    my $name = $AUTOLOAD;
-    $name =~ s/.*://;
-    if ( exists($self->{$name}) )
-    {
-        return( $self->{$name} );
-    }
-    Fatal( "Can't access $name member of object of class $class" );
-}
-
 sub open
 {
     my $self = shift;
