@@ -33,37 +33,33 @@
 // Class used for storing a box, which is defined as a region
 // defined by two coordinates
 //
-class Box
-{
+class Box {
 private:
   Coord lo, hi;
   Coord size;
 
 public:
-  inline Box()
-  {
-  }
+  inline Box() { }
   explicit inline Box( int p_size ) : lo( 0, 0 ), hi ( p_size-1, p_size-1 ), size( Coord::Range( hi, lo ) ) { }
   inline Box( int p_x_size, int p_y_size ) : lo( 0, 0 ), hi ( p_x_size-1, p_y_size-1 ), size( Coord::Range( hi, lo ) ) { }
   inline Box( int lo_x, int lo_y, int hi_x, int hi_y ) : lo( lo_x, lo_y ), hi( hi_x, hi_y ), size( Coord::Range( hi, lo ) ) { }
   inline Box( const Coord &p_lo, const Coord &p_hi ) : lo( p_lo ), hi( p_hi ), size( Coord::Range( hi, lo ) ) { }
 
-  inline const Coord &Lo() const { return( lo ); }
-  inline int LoX() const { return( lo.X() ); }
-  inline int LoY() const { return( lo.Y() ); }
-  inline const Coord &Hi() const { return( hi ); }
-  inline int HiX() const { return( hi.X() ); }
-  inline int HiY() const { return( hi.Y() ); }
-  inline const Coord &Size() const { return( size ); }
-  inline int Width() const { return( size.X() ); }
-  inline int Height() const { return( size.Y() ); }
-  inline int Area() const { return( size.X()*size.Y() ); }
+  inline const Coord &Lo() const { return lo; }
+  inline int LoX() const { return lo.X(); }
+  inline int LoY() const { return lo.Y(); }
+  inline const Coord &Hi() const { return hi; }
+  inline int HiX() const { return hi.X(); }
+  inline int HiY() const { return hi.Y(); }
+  inline const Coord &Size() const { return size; }
+  inline int Width() const { return size.X(); }
+  inline int Height() const { return size.Y(); }
+  inline int Area() const { return size.X()*size.Y(); }
 
-  inline const Coord Centre() const
-  {
+  inline const Coord Centre() const {
     int mid_x = int(round(lo.X()+(size.X()/2.0)));
     int mid_y = int(round(lo.Y()+(size.Y()/2.0)));
-    return( Coord( mid_x, mid_y ) );
+    return Coord( mid_x, mid_y );
   }
   inline bool Inside( const Coord &coord ) const
   {
