@@ -29,6 +29,10 @@
 
 #include "zm_utils.h"
 
+// Note that Error and Debug calls won't actually go anywhere unless you 
+// set the relevant ENV vars because the logger gets it's setting from the 
+// config.
+
 void zmLoadConfig() {
 
   // Process name, value pairs from the main config file first
@@ -40,83 +44,86 @@ void zmLoadConfig() {
   DIR* configSubFolder = opendir(ZM_CONFIG_SUBDIR);
   if ( configSubFolder ) { // subfolder exists and is readable
     char glob_pattern[PATH_MAX] = "";
-    snprintf( glob_pattern, sizeof(glob_pattern), "%s/*.conf", ZM_CONFIG_SUBDIR );
+    snprintf(glob_pattern, sizeof(glob_pattern), "%s/*.conf", ZM_CONFIG_SUBDIR);
 
     glob_t pglob;
-    int glob_status = glob( glob_pattern, 0, 0, &pglob );
+    int glob_status = glob(glob_pattern, 0, 0, &pglob);
     if ( glob_status != 0 ) {
       if ( glob_status < 0 ) {
-        Error( "Can't glob '%s': %s", glob_pattern, strerror(errno) );
+        Error("Can't glob '%s': %s", glob_pattern, strerror(errno));
       } else {
-        Debug( 1, "Can't glob '%s': %d", glob_pattern, glob_status );
+        Debug(1, "Can't glob '%s': %d", glob_pattern, glob_status);
       }
     } else {
       for ( unsigned int i = 0; i < pglob.gl_pathc; i++ ) {
         process_configfile(pglob.gl_pathv[i]);
       }
     }
-    globfree( &pglob );
+    globfree(&pglob);
     closedir(configSubFolder);
   }
 
-  zmDbConnect();
+  if ( !zmDbConnect() ) {
+    Fatal("Can't connect to db. Can't continue.");
+  }
   config.Load();
   config.Assign();
 
   // Populate the server config entries
-  if ( ! staticConfig.SERVER_ID ) {
-    if ( ! staticConfig.SERVER_NAME.empty() ) {
+  if ( !staticConfig.SERVER_ID ) {
+    if ( !staticConfig.SERVER_NAME.empty() ) {
 
-      Debug( 1, "Fetching ZM_SERVER_ID For Name = %s", staticConfig.SERVER_NAME.c_str() );
-      std::string sql = stringtf("SELECT Id FROM Servers WHERE Name='%s'", staticConfig.SERVER_NAME.c_str() );
+      Debug(1, "Fetching ZM_SERVER_ID For Name = %s", staticConfig.SERVER_NAME.c_str());
+      std::string sql = stringtf("SELECT `Id` FROM `Servers` WHERE `Name`='%s'",
+          staticConfig.SERVER_NAME.c_str());
       zmDbRow dbrow;
-      if ( dbrow.fetch( sql.c_str() ) ) {
+      if ( dbrow.fetch(sql.c_str()) ) {
         staticConfig.SERVER_ID = atoi(dbrow[0]);
       } else {
-        Fatal("Can't get ServerId for Server %s", staticConfig.SERVER_NAME.c_str() );
+        Fatal("Can't get ServerId for Server %s", staticConfig.SERVER_NAME.c_str());
       }
 
     } // end if has SERVER_NAME
   } else if ( staticConfig.SERVER_NAME.empty() ) {
-    Debug( 1, "Fetching ZM_SERVER_NAME For Id = %d", staticConfig.SERVER_ID );
-    std::string sql = stringtf("SELECT Name FROM Servers WHERE Id='%d'", staticConfig.SERVER_ID );
+    Debug(1, "Fetching ZM_SERVER_NAME For Id = %d", staticConfig.SERVER_ID);
+    std::string sql = stringtf("SELECT `Name` FROM `Servers` WHERE `Id`='%d'", staticConfig.SERVER_ID);
     
     zmDbRow dbrow;
-    if ( dbrow.fetch( sql.c_str() ) ) {
+    if ( dbrow.fetch(sql.c_str()) ) {
       staticConfig.SERVER_NAME = std::string(dbrow[0]);
     } else {
-      Fatal("Can't get ServerName for Server ID %d", staticConfig.SERVER_ID );
+      Fatal("Can't get ServerName for Server ID %d", staticConfig.SERVER_ID);
     }
 
     if ( staticConfig.SERVER_ID ) {
-        Debug( 3, "Multi-server configuration detected. Server is %d.", staticConfig.SERVER_ID );
+        Debug(3, "Multi-server configuration detected. Server is %d.", staticConfig.SERVER_ID);
     } else {
-        Debug( 3, "Single server configuration assumed because no Server ID or Name was specified." );
+        Debug(3, "Single server configuration assumed because no Server ID or Name was specified.");
     }
   }
 
-  snprintf( staticConfig.capture_file_format, sizeof(staticConfig.capture_file_format), "%%s/%%0%dd-capture.jpg", config.event_image_digits );
-  snprintf( staticConfig.analyse_file_format, sizeof(staticConfig.analyse_file_format), "%%s/%%0%dd-analyse.jpg", config.event_image_digits );
-  snprintf( staticConfig.general_file_format, sizeof(staticConfig.general_file_format), "%%s/%%0%dd-%%s", config.event_image_digits );
-  snprintf( staticConfig.video_file_format, sizeof(staticConfig.video_file_format), "%%s/%%s");
+  snprintf(staticConfig.capture_file_format, sizeof(staticConfig.capture_file_format), "%%s/%%0%dd-capture.jpg", config.event_image_digits);
+  snprintf(staticConfig.analyse_file_format, sizeof(staticConfig.analyse_file_format), "%%s/%%0%dd-analyse.jpg", config.event_image_digits);
+  snprintf(staticConfig.general_file_format, sizeof(staticConfig.general_file_format), "%%s/%%0%dd-%%s", config.event_image_digits);
+  snprintf(staticConfig.video_file_format, sizeof(staticConfig.video_file_format), "%%s/%%s");
 }
 
-void process_configfile( char* configFile) {
+void process_configfile(char* configFile) {
   FILE *cfg;
   char line[512];
-  if ( (cfg = fopen( configFile, "r")) == NULL ) {
-    Fatal( "Can't open %s: %s", configFile, strerror(errno) );
+  if ( (cfg = fopen(configFile, "r")) == NULL ) {
+    Fatal("Can't open %s: %s", configFile, strerror(errno));
     return;
   }
-  while ( fgets( line, sizeof(line), cfg ) != NULL ) {
+  while ( fgets(line, sizeof(line), cfg) != NULL ) {
     char *line_ptr = line;
 
     // Trim off any cr/lf line endings
-    int chomp_len = strcspn( line_ptr, "\r\n" );
+    int chomp_len = strcspn(line_ptr, "\r\n");
     line_ptr[chomp_len] = '\0';
 
     // Remove leading white space
-    int white_len = strspn( line_ptr, " \t" );
+    int white_len = strspn(line_ptr, " \t");
     line_ptr += white_len;
 
     // Check for comment or empty line
@@ -131,9 +138,9 @@ void process_configfile( char* configFile) {
     }
 
     // Now look for the '=' in the middle of the line
-    temp_ptr = strchr( line_ptr, '=' );
+    temp_ptr = strchr(line_ptr, '=');
     if ( !temp_ptr ) {
-      Warning( "Invalid data in %s: '%s'", configFile, line );
+      Warning("Invalid data in %s: '%s'", configFile, line);
       continue;
     }
 
@@ -148,51 +155,49 @@ void process_configfile( char* configFile) {
     } while ( *temp_ptr == ' ' || *temp_ptr == '\t' );
 
     // Remove leading white space and leading quotes from the value part
-    white_len = strspn( val_ptr, " \t" );
-    white_len += strspn( val_ptr, "\'\"" );
+    white_len = strspn(val_ptr, " \t");
+    white_len += strspn(val_ptr, "\'\"");
     val_ptr += white_len;
 
-    if ( strcasecmp( name_ptr, "ZM_DB_HOST" ) == 0 )
+    if ( strcasecmp(name_ptr, "ZM_DB_HOST") == 0 )
       staticConfig.DB_HOST = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_DB_NAME" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_DB_NAME") == 0 )
       staticConfig.DB_NAME = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_DB_USER" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_DB_USER") == 0 )
       staticConfig.DB_USER = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_DB_PASS" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_DB_PASS") == 0 )
       staticConfig.DB_PASS = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_DB_SSL_CA_CERT" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_DB_SSL_CA_CERT") == 0 )
       staticConfig.DB_SSL_CA_CERT = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_DB_SSL_CLIENT_KEY" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_DB_SSL_CLIENT_KEY") == 0 )
       staticConfig.DB_SSL_CLIENT_KEY = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_DB_SSL_CLIENT_CERT" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_DB_SSL_CLIENT_CERT") == 0 )
       staticConfig.DB_SSL_CLIENT_CERT = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_PATH_WEB" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_PATH_WEB") == 0 )
       staticConfig.PATH_WEB = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_SERVER_HOST" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_SERVER_HOST") == 0 )
       staticConfig.SERVER_NAME = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_SERVER_NAME" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_SERVER_NAME") == 0 )
       staticConfig.SERVER_NAME = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_SERVER_ID" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_SERVER_ID") == 0 )
       staticConfig.SERVER_ID = atoi(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_DIR_EVENTS" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_DIR_EVENTS") == 0 )
       staticConfig.DIR_EVENTS = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_DIR_IMAGES" ) == 0 )
-      staticConfig.DIR_IMAGES = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_DIR_SOUNDS" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_DIR_SOUNDS") == 0 )
       staticConfig.DIR_SOUNDS = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_DIR_EXPORTS" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_DIR_EXPORTS") == 0 )
       staticConfig.DIR_EXPORTS = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_PATH_ZMS" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_PATH_ZMS") == 0 )
       staticConfig.PATH_ZMS = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_PATH_MAP" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_PATH_MAP") == 0 )
       staticConfig.PATH_MAP = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_PATH_SOCKS" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_PATH_SOCKS") == 0 )
       staticConfig.PATH_SOCKS = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_PATH_LOGS" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_PATH_LOGS") == 0 )
       staticConfig.PATH_LOGS = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_PATH_SWAP" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_PATH_SWAP") == 0 )
       staticConfig.PATH_SWAP = std::string(val_ptr);
-    else if ( strcasecmp( name_ptr, "ZM_PATH_ARP" ) == 0 )
+    else if ( strcasecmp(name_ptr, "ZM_PATH_ARP") == 0 )
       staticConfig.PATH_ARP = std::string(val_ptr);
     else {
       // We ignore this now as there may be more parameters than the
@@ -200,18 +205,18 @@ void process_configfile( char* configFile) {
       // Warning( "Invalid parameter '%s' in %s", name_ptr, ZM_CONFIG );
     }
   } // end foreach line of the config
-  fclose( cfg );
+  fclose(cfg);
 }
 
 StaticConfig staticConfig;
 
-ConfigItem::ConfigItem( const char *p_name, const char *p_value, const char *const p_type ) {
+ConfigItem::ConfigItem(const char *p_name, const char *p_value, const char *const p_type) {
   name = new char[strlen(p_name)+1];
-  strcpy( name, p_name );
+  strcpy(name, p_name);
   value = new char[strlen(p_value)+1];
-  strcpy( value, p_value );
+  strcpy(value, p_value);
   type = new char[strlen(p_type)+1];
-  strcpy( type, p_type );
+  strcpy(type, p_type);
 
   //Info( "Created new config item %s = %s (%s)\n", name, value, type );
 
@@ -219,28 +224,28 @@ ConfigItem::ConfigItem( const char *p_name, const char *p_value, const char *con
   accessed = false;
 }
 
-ConfigItem::ConfigItem( const ConfigItem &item ) {
+ConfigItem::ConfigItem(const ConfigItem &item) {
   name = new char[strlen(item.name)+1];
-  strcpy( name, item.name );
+  strcpy(name, item.name);
   value = new char[strlen(item.value)+1];
-  strcpy( value, item.value );
+  strcpy(value, item.value);
   type = new char[strlen(item.type)+1];
-  strcpy( type, item.type );
+  strcpy(type, item.type);
 
   //Info( "Created new config item %s = %s (%s)\n", name, value, type );
 
   accessed = false;
 }
-void ConfigItem::Copy( const ConfigItem &item ) {
+void ConfigItem::Copy(const ConfigItem &item) {
   if (name) delete name;
   name = new char[strlen(item.name)+1];
-  strcpy( name, item.name );
+  strcpy(name, item.name);
   if (value) delete value;
   value = new char[strlen(item.value)+1];
-  strcpy( value, item.value );
+  strcpy(value, item.value);
   if (type) delete type;
   type = new char[strlen(item.type)+1];
-  strcpy( type, item.type );
+  strcpy(type, item.type);
 
   //Info( "Created new config item %s = %s (%s)\n", name, value, type );
   accessed = false;
@@ -255,16 +260,16 @@ ConfigItem::~ConfigItem() {
 void ConfigItem::ConvertValue() const {
   if ( !strcmp( type, "boolean" ) ) {
     cfg_type = CFG_BOOLEAN;
-    cfg_value.boolean_value = (bool)strtol( value, 0, 0 );
-  } else if ( !strcmp( type, "integer" ) ) {
+    cfg_value.boolean_value = (bool)strtol(value, 0, 0);
+  } else if ( !strcmp(type, "integer") ) {
     cfg_type = CFG_INTEGER;
-    cfg_value.integer_value = strtol( value, 0, 10 );
-  } else if ( !strcmp( type, "hexadecimal" ) ) {
+    cfg_value.integer_value = strtol(value, 0, 10);
+  } else if ( !strcmp(type, "hexadecimal") ) {
     cfg_type = CFG_INTEGER;
-    cfg_value.integer_value = strtol( value, 0, 16 );
-  } else if ( !strcmp( type, "decimal" ) ) {
+    cfg_value.integer_value = strtol(value, 0, 16);
+  } else if ( !strcmp(type, "decimal") ) {
     cfg_type = CFG_DECIMAL;
-    cfg_value.decimal_value = strtod( value, 0 );
+    cfg_value.decimal_value = strtod(value, 0);
   } else {
     cfg_type = CFG_STRING;
     cfg_value.string_value = value;
@@ -277,11 +282,11 @@ bool ConfigItem::BooleanValue() const {
     ConvertValue();
 
   if ( cfg_type != CFG_BOOLEAN ) {
-    Error( "Attempt to fetch boolean value for %s, actual type is %s. Try running 'zmupdate.pl -f' to reload config.", name, type );
-    exit( -1 );
+    Error("Attempt to fetch boolean value for %s, actual type is %s. Try running 'zmupdate.pl -f' to reload config.", name, type);
+    exit(-1);
   }
 
-  return( cfg_value.boolean_value );
+  return cfg_value.boolean_value;
 }
 
 int ConfigItem::IntegerValue() const {
@@ -289,11 +294,11 @@ int ConfigItem::IntegerValue() const {
     ConvertValue();
 
   if ( cfg_type != CFG_INTEGER ) {
-    Error( "Attempt to fetch integer value for %s, actual type is %s. Try running 'zmupdate.pl -f' to reload config.", name, type );
-    exit( -1 );
+    Error("Attempt to fetch integer value for %s, actual type is %s. Try running 'zmupdate.pl -f' to reload config.", name, type);
+    exit(-1);
   }
 
-  return( cfg_value.integer_value );
+  return cfg_value.integer_value;
 }
 
 double ConfigItem::DecimalValue() const {
@@ -301,11 +306,11 @@ double ConfigItem::DecimalValue() const {
     ConvertValue();
 
   if ( cfg_type != CFG_DECIMAL ) {
-    Error( "Attempt to fetch decimal value for %s, actual type is %s. Try running 'zmupdate.pl -f' to reload config.", name, type );
-    exit( -1 );
+    Error("Attempt to fetch decimal value for %s, actual type is %s. Try running 'zmupdate.pl -f' to reload config.", name, type);
+    exit(-1);
   }
 
-  return( cfg_value.decimal_value );
+  return cfg_value.decimal_value;
 }
 
 const char *ConfigItem::StringValue() const {
@@ -313,11 +318,11 @@ const char *ConfigItem::StringValue() const {
     ConvertValue();
 
   if ( cfg_type != CFG_STRING ) {
-    Error( "Attempt to fetch string value for %s, actual type is %s. Try running 'zmupdate.pl -f' to reload config.", name, type );
-    exit( -1 );
+    Error("Attempt to fetch string value for %s, actual type is %s. Try running 'zmupdate.pl -f' to reload config.", name, type);
+    exit(-1);
   }
 
-  return( cfg_value.string_value );
+  return cfg_value.string_value;
 }
 
 Config::Config() {
@@ -339,54 +344,54 @@ Config::~Config() {
 void Config::Load() {
   static char sql[ZM_SQL_SML_BUFSIZ];
    
-  strncpy( sql, "select Name, Value, Type from Config order by Id", sizeof(sql) );
-  if ( mysql_query( &dbconn, sql ) ) {
-    Error( "Can't run query: %s", mysql_error( &dbconn ) );
-    exit( mysql_errno( &dbconn ) );
+  strncpy(sql, "SELECT `Name`, `Value`, `Type` FROM `Config` ORDER BY `Id`", sizeof(sql) );
+  if ( mysql_query(&dbconn, sql) ) {
+    Error("Can't run query: %s", mysql_error(&dbconn));
+    exit(mysql_errno(&dbconn));
   }
 
-  MYSQL_RES *result = mysql_store_result( &dbconn );
+  MYSQL_RES *result = mysql_store_result(&dbconn);
   if ( !result ) {
-    Error( "Can't use query result: %s", mysql_error( &dbconn ) );
-    exit( mysql_errno( &dbconn ) );
+    Error("Can't use query result: %s", mysql_error(&dbconn));
+    exit(mysql_errno(&dbconn));
   }
-  n_items = mysql_num_rows( result );
+  n_items = mysql_num_rows(result);
 
   if ( n_items <= ZM_MAX_CFG_ID ) {
-    Error( "Config mismatch, expected %d items, read %d. Try running 'zmupdate.pl -f' to reload config.", ZM_MAX_CFG_ID+1, n_items );
-    exit( -1 );
+    Error("Config mismatch, expected %d items, read %d. Try running 'zmupdate.pl -f' to reload config.", ZM_MAX_CFG_ID+1, n_items);
+    exit(-1);
   }
 
   items = new ConfigItem *[n_items];
-  for( int i = 0; MYSQL_ROW dbrow = mysql_fetch_row( result ); i++ ) {
-    items[i] = new ConfigItem( dbrow[0], dbrow[1], dbrow[2] );
+  for( int i = 0; MYSQL_ROW dbrow = mysql_fetch_row(result); i++ ) {
+    items[i] = new ConfigItem(dbrow[0], dbrow[1], dbrow[2]);
   }
-  mysql_free_result( result );
+  mysql_free_result(result);
 }
 
 void Config::Assign() {
 ZM_CFG_ASSIGN_LIST
 }
 
-const ConfigItem &Config::Item( int id ) {
+const ConfigItem &Config::Item(int id) {
   if ( !n_items ) {
     Load();
     Assign();
   }
 
   if ( id < 0 || id > ZM_MAX_CFG_ID ) {
-    Error( "Attempt to access invalid config, id = %d. Try running 'zmupdate.pl -f' to reload config.", id );
-    exit( -1 );
+    Error("Attempt to access invalid config, id = %d. Try running 'zmupdate.pl -f' to reload config.", id);
+    exit(-1);
   }
 
   ConfigItem *item = items[id];
   
   if ( !item ) {
-    Error( "Can't find config item %d", id );
-    exit( -1 );
+    Error("Can't find config item %d", id);
+    exit(-1);
   }
     
-  return( *item );
+  return *item;
 }
 
 Config config;
