@@ -32,7 +32,7 @@ bool zmDbConnect() {
   // For some reason having these lines causes memory corruption and crashing on newer debian/ubuntu
 	// But they really need to be here in order to prevent a double open of mysql
   if ( zmDbConnected )  {
-    Warning("Calling zmDbConnect when already connected");
+    //Warning("Calling zmDbConnect when already connected");
     return true;
   }
 
@@ -40,7 +40,7 @@ bool zmDbConnect() {
     Error("Can't initialise database connection: %s", mysql_error(&dbconn));
     return false;
   }
-  my_bool reconnect = 1;
+  bool reconnect = 1;
   if ( mysql_options(&dbconn, MYSQL_OPT_RECONNECT, &reconnect) )
     Error("Can't set database auto reconnect option: %s", mysql_error(&dbconn));
   if ( !staticConfig.DB_SSL_CA_CERT.empty() )
@@ -81,10 +81,11 @@ bool zmDbConnect() {
 void zmDbClose() {
   if ( zmDbConnected ) {
     db_mutex.lock();
-    mysql_close( &dbconn );
+    mysql_close(&dbconn);
     // mysql_init() call implicitly mysql_library_init() but
     // mysql_close() does not call mysql_library_end()
-    mysql_library_end();
+    // We get segfaults and a hang when we call this.  So just don't.
+    //mysql_library_end();
     zmDbConnected = false;
     db_mutex.unlock();
   }
@@ -96,6 +97,12 @@ MYSQL_RES * zmDbFetch(const char * query) {
     return NULL;
   }
   db_mutex.lock();
+  // Might have been disconnected while we waited for the lock
+  if ( !zmDbConnected ) {
+    db_mutex.unlock();
+    Error("Not connected.");
+    return NULL;
+  }
 
   if ( mysql_query(&dbconn, query) ) {
     db_mutex.unlock();
