@@ -54,11 +54,13 @@ class EventStream : public StreamBase {
       uint64_t  event_id;
       unsigned long   monitor_id;
       unsigned long   storage_id;
-      unsigned long   frame_count;
+      unsigned long   frame_count;    // Value of Frames column in Event
+      unsigned long   last_frame_id;  // Highest frame id known about. Can be < frame_count in incomplete events
       time_t          start_time;
+      time_t          end_time;
       double          duration;
       char            path[PATH_MAX];
-      int             n_frames;
+      int             n_frames;       // # of frame rows returned from database
       FrameData       *frames;
       char            video_file[PATH_MAX];
       Storage::Schemes  scheme;
