@@ -764,25 +764,6 @@ int FfmpegCamera::CaptureAndRecord(
       return -1;
     }
 
-    if ( (packet.pts != AV_NOPTS_VALUE) && (packet.pts < -100000) ) {
-      // Ignore packets that have crazy negative pts.
-      // They aren't supposed to happen.
-      Warning("Ignore packet because pts %" PRId64 " is massively negative."
-         " Error count is %d", packet.pts, error_count);
-      dumpPacket(
-          mFormatContext->streams[packet.stream_index],
-          &packet,
-          "Ignored packet");
-      if ( error_count > 100 ) {
-        Error("Bad packet count over 100, going to close and re-open stream");
-        return -1;
-      }
-      error_count += 1;
-      continue;
-    }
-    // If we get a good frame, decrease the error count.. We could zero it...
-    if ( error_count > 0 ) error_count -= 1;
-
     int keyframe = packet.flags & AV_PKT_FLAG_KEY;
     bytes += packet.size;
     dumpPacket(
