@@ -41,13 +41,13 @@ protected:
     static int CompareYX( const void *p1, const void *p2 ) {
         const Edge *e1 = reinterpret_cast<const Edge *>(p1), *e2 = reinterpret_cast<const Edge *>(p2);
       if ( e1->min_y == e2->min_y )
-        return( int(e1->min_x - e2->min_x) );
+        return int(e1->min_x - e2->min_x);
       else
-        return( int(e1->min_y - e2->min_y) );
+        return int(e1->min_y - e2->min_y);
     }
     static int CompareX( const void *p1, const void *p2 ) {
       const Edge *e1 = reinterpret_cast<const Edge *>(p1), *e2 = reinterpret_cast<const Edge *>(p2);
-      return( int(e1->min_x - e2->min_x) );
+      return int(e1->min_x - e2->min_x);
     }
   };
 
@@ -83,32 +83,32 @@ protected:
   void calcCentre();
 
 public:
-  inline Polygon() : n_coords( 0 ), coords( 0 ), area( 0 ), edges(0), slices(0) {
+  inline Polygon() : n_coords(0), coords(0), area(0), edges(0), slices(0) {
   }
-  Polygon( int p_n_coords, const Coord *p_coords );
-  Polygon( const Polygon &p_polygon );
+  Polygon(int p_n_coords, const Coord *p_coords);
+  Polygon(const Polygon &p_polygon);
   ~Polygon() {
     delete[] coords;
   }
 
   Polygon &operator=( const Polygon &p_polygon );
 
-  inline int getNumCoords() const { return( n_coords ); }
+  inline int getNumCoords() const { return n_coords; }
   inline const Coord &getCoord( int index ) const {
-    return( coords[index] );
+    return coords[index];
   }
 
-  inline const Box &Extent() const { return( extent ); }
-  inline int LoX() const { return( extent.LoX() ); }
-  inline int HiX() const { return( extent.HiX() ); }
-  inline int LoY() const { return( extent.LoY() ); }
-  inline int HiY() const { return( extent.HiY() ); }
-  inline int Width() const { return( extent.Width() ); }
-  inline int Height() const { return( extent.Height() ); }
+  inline const Box &Extent() const { return extent; }
+  inline int LoX() const { return extent.LoX(); }
+  inline int HiX() const { return extent.HiX(); }
+  inline int LoY() const { return extent.LoY(); }
+  inline int HiY() const { return extent.HiY(); }
+  inline int Width() const { return extent.Width(); }
+  inline int Height() const { return extent.Height(); }
 
-  inline int Area() const { return( area ); }
+  inline int Area() const { return area; }
   inline const Coord &Centre() const {
-    return( centre );
+    return centre;
   }
   bool isInside( const Coord &coord ) const;
 };
