@@ -58,7 +58,7 @@ public:
   int Capture( Image &image );
   int PostCapture();
   int CaptureAndRecord( Image &image, timeval recording, char* event_directory ) {return 0;};
-  int Close() { return 0; };
+  int Close() { Disconnect(); return 0; };
 };
 
 #endif // ZM_REMOTE_CAMERA_HTTP_H
