@@ -19,9 +19,6 @@
 #ifndef ZM_RTSP_AUTH_H
 #define ZM_RTSP_AUTH_H
 
-#if HAVE_GNUTLS_OPENSSL_H
-#include <gnutls/openssl.h>
-#endif
 #if HAVE_GNUTLS_GNUTLS_H
 #include <gnutls/gnutls.h>
 #endif
