@@ -36,6 +36,7 @@ public:
 
 protected:
   static const int MAX_STREAM_DELAY = 5; // Seconds
+  static const int MAX_SLEEP_USEC = 500000; // .5 Seconds
 
   static const StreamType DEFAULT_TYPE = STREAM_JPEG;
   enum { DEFAULT_RATE=ZM_RATE_BASE };
@@ -65,19 +66,22 @@ protected:
   const char *format;
   int replay_rate;
   int scale;
+  int last_scale;
   int zoom;
+  int last_zoom;
   double maxfps;
   int bitrate;
+  unsigned short last_x, last_y;
   unsigned short x, y;
 
 protected:
   int connkey;
   int sd;
-  char loc_sock_path[PATH_MAX];
+  char loc_sock_path[108];
   struct sockaddr_un loc_addr;
-  char rem_sock_path[PATH_MAX];
+  char rem_sock_path[108];
   struct sockaddr_un rem_addr;
-  char sock_path_lock[PATH_MAX];
+  char sock_path_lock[108];
   int lock_fd;
 
 protected:
@@ -116,15 +120,15 @@ public:
     type = DEFAULT_TYPE;
     format = "";
     replay_rate = DEFAULT_RATE;
-    scale = DEFAULT_SCALE;
-    zoom = DEFAULT_ZOOM;
+    last_scale = scale = DEFAULT_SCALE;
+    last_zoom = zoom = DEFAULT_ZOOM;
     maxfps = DEFAULT_MAXFPS;
     bitrate = DEFAULT_BITRATE;
 
     paused = false;
     step = 0;
-    x = 0;
-    y = 0;
+    last_x = x = 0;
+    last_y = y = 0;
 
     connkey = 0;
     sd = -1;
@@ -160,6 +164,7 @@ public:
       scale = DEFAULT_SCALE;
   }
   void setStreamReplayRate( int p_rate ) {
+    Debug(2,"Setting replay_rate %d", p_rate);
     replay_rate = p_rate;
   }
   void setStreamMaxFPS( double p_maxfps ) {
