@@ -20,9 +20,12 @@
 #ifndef ZM_THREAD_H
 #define ZM_THREAD_H
 
+class RecursiveMutex;
+
+
+#include "zm_config.h"
 #include <unistd.h>
 #include <pthread.h>
-#include <unistd.h>
 #ifdef HAVE_SYS_SYSCALL_H
 #include <sys/syscall.h>
 #endif // HAVE_SYS_SYSCALL_H
