@@ -3,8 +3,6 @@ App::uses('AppModel', 'Model');
 /**
  * User Model
  *
- * @property Monitor $Monitor
- * @property Frame $Frame
  */
 class User extends AppModel {
 
@@ -23,6 +21,20 @@ class User extends AppModel {
         )
     );
 
+    function beforeFind($query) {
+      if ( empty($query['fields']) ) {
+        $schema = $this->schema();
+        unset($schema['Password']);
+
+        foreach (array_keys($schema) as $field) {
+          $query['fields'][] = $this->alias . '.' . $field;
+        }
+        return $query;
+      }
+      return parent::beforeFind($query);
+    }
+
+
 /**
  * Use table
  *
@@ -53,14 +65,6 @@ class User extends AppModel {
  * @var array
  */
 	public $belongsTo = array(
-		/*'Monitor' => array(
-			'className' => 'Monitor',
-			'foreignKey' => 'MonitorId',
-			'conditions' => '',
-			'fields' => '',
-			'order' => ''
-		)
-*/
 	);
 
 /**
@@ -69,21 +73,6 @@ class User extends AppModel {
  * @var array
  */
 	public $hasMany = array(
-/*
-		'Frame' => array(
-			'className' => 'Frame',
-			'foreignKey' => 'UserId',
-			'dependent' => true,
-			'conditions' => '',
-			'fields' => '',
-			'order' => '',
-			'limit' => '',
-			'offset' => '',
-			'exclusive' => '',
-			'finderQuery' => '',
-			'counterQuery' => ''
-		)
-*/
 	);
 
 }
