@@ -205,6 +205,7 @@ $SLANG = array(
     'CanMoveRel'           => 'Umí relativní pohyb',
     'CanPan'               => 'Umí otáčení',
     'CanReset'             => 'Umí reset',
+	'CanReboot'             => 'Can Reboot',
     'CanSetPresets'        => 'Umí navolit předvolby',
     'CanSleep'             => 'Může spát',
     'CanTilt'              => 'Umí náklon',
@@ -288,7 +289,7 @@ $SLANG = array(
     'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Donate'               => 'Prosím podpořte',
     'DonateAlready'        => 'Ne, už jsem podpořil',
-    'DonateEnticement'     => 'Již nějakou dobu používáte software ZoneMinder k ochraně svého majetku a předpokládám, že jej shledáváte užitečným. Přestože je ZoneMinder, znovu připomínám, zdarma a volně šířený software, stojí jeho vývoj a podpora nějaké peníze. Pokud byste chtěl/a podpořit budoucí vývoj a nové možnosti softwaru, prosím zvažte darování finanční pomoci. Darování je, samozřejmě, dobrovolné, ale zato velmi ceněné můžete přispět jakou částkou chcete.<br><br>Pokud máte zájem podpořit náš tým, prosím, vyberte níže uvedenou možnost, nebo navštivte http://www.zoneminder.com/donate.html.<br><br>Děkuji Vám že jste si vybral/a software ZoneMinder a nezapomeňte navštívit fórum na ZoneMinder.com pro podporu a návrhy jak udělat ZoneMinder ještě lepším než je dnes.',
+    'DonateEnticement'     => 'Již nějakou dobu používáte software ZoneMinder k ochraně svého majetku a předpokládám, že jej shledáváte užitečným. Přestože je ZoneMinder, znovu připomínám, zdarma a volně šířený software, stojí jeho vývoj a podpora nějaké peníze. Pokud byste chtěl/a podpořit budoucí vývoj a nové možnosti softwaru, prosím zvažte darování finanční pomoci. Darování je, samozřejmě, dobrovolné, ale zato velmi ceněné můžete přispět jakou částkou chcete.<br><br>Pokud máte zájem podpořit náš tým, prosím, vyberte níže uvedenou možnost, nebo navštivte https://zoneminder.com/donate/.<br><br>Děkuji Vám že jste si vybral/a software ZoneMinder a nezapomeňte navštívit fórum na ZoneMinder.com pro podporu a návrhy jak udělat ZoneMinder ještě lepším než je dnes.',
     'DonateRemindDay'      => 'Nyní ne, připomenout za 1 den',
     'DonateRemindHour'     => 'Nyní ne, připomenout za hodinu',
     'DonateRemindMonth'    => 'Nyní ne, připomenout za měsíc',
