@@ -979,9 +979,8 @@ $OLANG = array(
     'Help' => '
       Parameters in this field are passed on to FFmpeg. Multiple parameters can be separated by ,~~
       Examples (do not enter quotes)~~~~
-      "allowed_media_types=video" Set datatype to request fromcam (audio, video, data)~~~~
-      "reorder_queue_size=nnn" Set number of packets to buffer for handling of reordered packets~~~~
-      "loglevel=debug" Set verbosity of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)
+      "allowed_media_types=video" Set datatype to request from cam (audio, video, data)~~~~
+      "reorder_queue_size=nnn" Set number of packets to buffer for handling of reordered packets
     '
 	),
   'OPTIONS_ENCODER_PARAMETERS' => array(
