@@ -205,6 +205,7 @@ $SLANG = array(
     'CanMoveRel'            => 'Puede moverse de forma relativa',
     'CanPan'                => 'Puede desplazarse' ,
     'CanReset'              => 'Puede restablecerse',
+	'CanReboot'             => 'Can Reboot',
     'CanSetPresets'         => 'Puede fefinir programaciones',
     'CanSleep'              => 'Puede dormirse',
     'CanTilt'               => 'Puede inclinarse',
@@ -288,7 +289,7 @@ $SLANG = array(
     'DoNativeMotionDetection'=> 'Do Native Motion Detection', // Added - 2015-04-18
     'Donate'                => 'Por favor, done',
     'DonateAlready'         => 'No, ya he donado',
-    'DonateEnticement'      => 'Ha estado ejecutando ZoneMinder por un tiempo y con suerte le resultará un útil complemento para su seguridad en hogar y trabajo. Aunque ZoneMinder es, y será, libre y de código abierto, cuesta dinero desarrollarlo y mantenerlo. Si quiere ayudar a mantener un futuro desarrollo y nuevas funciones entonces considere hacer un donativo por favor. Donar es, por supuesto, opcional pero muy apreciado y puede donar tanto como desee sin importar la cantidad.<br/><br/>Si desea hacer una donación por favor seleccione la opción de debajo o vaya a http://www.zoneminder.com/donate.html en su navegador.<br/><br/>Muchas gracias por usar ZoneMinder y no se olvide de vistar los foros en ZoneMinder.com para obtener soporte o hacer sugerencias sobre cómo mejorar su experiencia con ZoneMinder aún más.',
+    'DonateEnticement'      => 'Ha estado ejecutando ZoneMinder por un tiempo y con suerte le resultará un útil complemento para su seguridad en hogar y trabajo. Aunque ZoneMinder es, y será, libre y de código abierto, cuesta dinero desarrollarlo y mantenerlo. Si quiere ayudar a mantener un futuro desarrollo y nuevas funciones entonces considere hacer un donativo por favor. Donar es, por supuesto, opcional pero muy apreciado y puede donar tanto como desee sin importar la cantidad.<br/><br/>Si desea hacer una donación por favor seleccione la opción de debajo o vaya a https://zoneminder.com/donate/ en su navegador.<br/><br/>Muchas gracias por usar ZoneMinder y no se olvide de vistar los foros en ZoneMinder.com para obtener soporte o hacer sugerencias sobre cómo mejorar su experiencia con ZoneMinder aún más.',
     'DonateRemindDay'       => 'Aún no, recordarme de nuevo en 1 día',
     'DonateRemindHour'      => 'Aún no, recordarme de nuevo en 1 hora',
     'DonateRemindMonth'     => 'Aún no, recordarme de nuevo en 1 mes',
