@@ -212,6 +212,7 @@ $SLANG = array(
     'CanMoveRel'            => 'Can Move Relative',
     'CanPan'                => 'Can Pan' ,
     'CanReset'              => 'Can Reset',
+	'CanReboot'             => 'Can Reboot',
     'CanSetPresets'         => 'Can Set Presets',
     'CanSleep'              => 'Can Sleep',
     'CanTilt'               => 'Can Tilt',
@@ -295,7 +296,7 @@ $SLANG = array(
     'DoNativeMotionDetection'=> 'Do Native Motion Detection', // Added - 2015-04-18
     'Donate'                => 'Palun Anneta',
     'DonateAlready'         => 'EI, Ma olen juba annetanud',
-    'DonateEnticement'      => 'Sa oled juba kasutanud ZoneMinderit juba mõnda aega. Nüüd kus sa oled leidnud, et see on kasulik lisa sinu kodule  või sinu töökohale. Kuigi ZoneMinder on, jääb alatiseks, vabaks ja avatud lähtekoodiks, siiski selle arendamiseks kulub aega ja raha. Kui sa soovid meid aidata, siis toeta meid tuleviku arendusteks ja uute lisade loomiseks. Palun mõelge annetuse peale. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br/><br/>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br/><br/>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
+    'DonateEnticement'      => 'Sa oled juba kasutanud ZoneMinderit juba mõnda aega. Nüüd kus sa oled leidnud, et see on kasulik lisa sinu kodule  või sinu töökohale. Kuigi ZoneMinder on, jääb alatiseks, vabaks ja avatud lähtekoodiks, siiski selle arendamiseks kulub aega ja raha. Kui sa soovid meid aidata, siis toeta meid tuleviku arendusteks ja uute lisade loomiseks. Palun mõelge annetuse peale. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br/><br/>If you would like to donate please select the option below or go to https://zoneminder.com/donate/ in your browser.<br/><br/>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
     'DonateRemindDay'       => 'Ei veel, tuleta meelde ühe päeva pärast',
     'DonateRemindHour'      => 'Ei veel, tuleta meelde ühe tunni pärast',
     'DonateRemindMonth'     => 'Ei veel, tuleta meelde ühe kuu pärast',
