@@ -211,6 +211,7 @@ $SLANG = array(
     'CanMoveRel'           => 'Relatif',
     'CanPan'               => 'Panoramique' ,
     'CanReset'             => 'RàZ',
+	'CanReboot'             => 'Can Reboot',
     'CanSetPresets'        => 'Stockage prépos.',
     'CanSleep'             => 'Veille',
     'CanTilt'              => 'Inclinaison',
@@ -294,7 +295,7 @@ $SLANG = array(
     'DoNativeMotionDetection'=> 'Réaliser détection native',
     'Donate'               => 'Veuillez faire un don',
     'DonateAlready'        => 'Non, j\'ai déjà donné',
-    'DonateEnticement'     => 'Vous utilisez ZoneMinder depuis quelque temps et nous espérons que vous trouvez cette solution utile. Bien que ZoneMinder est, et restera, une solution libre et ouverte (open source), son développement et son maintien nécessitent des moyens financiers. Si vous voulez aider au développement et à l\'ajout de fonctionnalités, veuillez considérer la possibilité d\'effectuer un don. Les dons sont bien sûr optionnels mais grandement appréciés et vous pouvez donner le montant que vous désirez.<br><br>Si vous voulez effectuer un don, veuillez sélectionner l\'option ci-dessous ou veuillez vous rendre sur http://www.zoneminder.com/donate.html à l\'aide de votre navigateur internet.<br><br>Merci d\'utiliser ZoneMinder et n\'oubliez pas de visiter les forums sur ZoneMinder.com pour le support ou des suggestions pour rendre votre expérience de ZoneMinder encore meilleure.',
+    'DonateEnticement'     => 'Vous utilisez ZoneMinder depuis quelque temps et nous espérons que vous trouvez cette solution utile. Bien que ZoneMinder est, et restera, une solution libre et ouverte (open source), son développement et son maintien nécessitent des moyens financiers. Si vous voulez aider au développement et à l\'ajout de fonctionnalités, veuillez considérer la possibilité d\'effectuer un don. Les dons sont bien sûr optionnels mais grandement appréciés et vous pouvez donner le montant que vous désirez.<br><br>Si vous voulez effectuer un don, veuillez sélectionner l\'option ci-dessous ou veuillez vous rendre sur https://zoneminder.com/donate/ à l\'aide de votre navigateur internet.<br><br>Merci d\'utiliser ZoneMinder et n\'oubliez pas de visiter les forums sur ZoneMinder.com pour le support ou des suggestions pour rendre votre expérience de ZoneMinder encore meilleure.',
     'DonateRemindDay'      => 'Pas encore, me rappeler dans 1 jour',
     'DonateRemindHour'     => 'Pas encore, me rappeler dans 1 heure',
     'DonateRemindMonth'    => 'Pas encore, me rappeler dans 1 mois',
