@@ -248,6 +248,7 @@ $SLANG = array(
     'CanMoveRel'           => 'Relatíven tud mozogni',
     'CanPan'               => 'Tud jobb-bal mozgást' ,
     'CanReset'             => 'Tud alaphelyzetbe jönni',
+	'CanReboot'             => 'Can Reboot',
     'CanSetPresets'        => 'Tud menteni profilokat',
     'CanSleep'             => 'Tud phihenő üzemmódot',
     'CanTilt'              => 'Tud fel-le mozgást',
@@ -331,7 +332,7 @@ $SLANG = array(
     'DoNativeMotionDetection'=> 'Do Native Motion Detection', // Added - 2015-04-18
     'Donate'               => 'Kérem támogasson',
     'DonateAlready'        => 'Nem, én már támogattam',
-    'DonateEnticement'     => 'Ön már jó ideje használja a ZoneMindert, és reméljük hasznos eszköznek tartja háza vagy munkahelye biztonságában. Bár a ZoneMinder egy szabad, nyílt forráskódú termék és az is marad, a fejlesztése pénzbe kerül. Ha van lehetősége támogatni a jövőbeni fejlesztéseket és az új funkciókat kérem, tegye meg. A támogatás teljesen önkéntes, de nagyon megbecsült és mértéke is tetszőleges.<br><br>Ha támogatni szertne, kérem, válasszon az alábbi lehetőségekből vagy látogassa meg a http://www.zoneminder.com/donate.html oldalt.<br><br>Köszönjük, hogy használja a ZoneMinder-t és ne felejtse el meglátogatni a fórumokat a ZoneMinder.com oldalon támogatásért és ötletekért, hogy a jövőben is még jobban ki tudja használni a ZoneMinder lehetőségeit.',
+    'DonateEnticement'     => 'Ön már jó ideje használja a ZoneMindert, és reméljük hasznos eszköznek tartja háza vagy munkahelye biztonságában. Bár a ZoneMinder egy szabad, nyílt forráskódú termék és az is marad, a fejlesztése pénzbe kerül. Ha van lehetősége támogatni a jövőbeni fejlesztéseket és az új funkciókat kérem, tegye meg. A támogatás teljesen önkéntes, de nagyon megbecsült és mértéke is tetszőleges.<br><br>Ha támogatni szertne, kérem, válasszon az alábbi lehetőségekből vagy látogassa meg a https://zoneminder.com/donate/ oldalt.<br><br>Köszönjük, hogy használja a ZoneMinder-t és ne felejtse el meglátogatni a fórumokat a ZoneMinder.com oldalon támogatásért és ötletekért, hogy a jövőben is még jobban ki tudja használni a ZoneMinder lehetőségeit.',
     'DonateRemindDay'      => 'Nem most, figyelmeztessen egy nap múlva',
     'DonateRemindHour'     => 'Nem most, figyelmeztessen egy óra múlva',
     'DonateRemindMonth'    => 'Nem most, figyelmeztessen egy hónap múlva',
