@@ -210,6 +210,7 @@ $SLANG = array(
     'CanMoveRel'           => 'Puo\' Mov. Relativo',
     'CanPan'               => 'Puo\' Pan' ,
     'CanReset'             => 'Puo\' Reset',
+	'CanReboot'             => 'Can Reboot',
     'CanSetPresets'        => 'Puo\' impostare preset',
     'CanSleep'             => 'Puo\' andare in sleep',
     'CanTilt'              => 'Puo\' Tilt',
@@ -293,7 +294,7 @@ $SLANG = array(
     'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Donate'               => 'Donate,per favore',
     'DonateAlready'        => 'No, ho gia donato...    ',
-    'DonateEnticement'     => 'Stai usando ZoneMinder da un po\' di tempo e spero che tu lo stia trovando utile per la sicurezza di casa tua o del tuo posto di lavoro..Anche se ZoneMinder e\' distribuito liberamente come software libero,costa soldi sia svilupparlo che supportarlo. Se preferisci che questo software continui ad avere supporto e sviluppo in futuro allora considera l\idea di fare una piccola donazione. Donare e\' ovviamente opzionale, ma apprezzato e puoi donare quanto vuoi,quel poco o tanto che tu desideri.<br><br>Se hai voglia per cortesia seleziona l\'opzione sotto o punta il tuo browser a http://www.zoneminder.com/donate.html .<br><br>Grazie per usare ZoneMinder e non dimenticare di visitare il forum in ZoneMinder.com se cerchi supporto o hai suggerimenti riguardo a come rendere migliore Zoneminder.',
+    'DonateEnticement'     => 'Stai usando ZoneMinder da un po\' di tempo e spero che tu lo stia trovando utile per la sicurezza di casa tua o del tuo posto di lavoro..Anche se ZoneMinder e\' distribuito liberamente come software libero,costa soldi sia svilupparlo che supportarlo. Se preferisci che questo software continui ad avere supporto e sviluppo in futuro allora considera l\idea di fare una piccola donazione. Donare e\' ovviamente opzionale, ma apprezzato e puoi donare quanto vuoi,quel poco o tanto che tu desideri.<br><br>Se hai voglia per cortesia seleziona l\'opzione sotto o punta il tuo browser a https://zoneminder.com/donate/ .<br><br>Grazie per usare ZoneMinder e non dimenticare di visitare il forum in ZoneMinder.com se cerchi supporto o hai suggerimenti riguardo a come rendere migliore Zoneminder.',
     'DonateRemindDay'      => 'Non ancora, ricordamelo ancora tra 1 giorno',
     'DonateRemindHour'     => 'Non ancora, ricordamelo ancora tra 1 ora',
     'DonateRemindMonth'    => 'Non ancora, ricordamelo ancora tra 1 mese',
