@@ -145,6 +145,7 @@ $SLANG = array(
     'CanMoveRel'           => 'Can Move Relative',
     'CanPan'               => 'Can Pan' ,
     'CanReset'             => 'Can Reset',
+	'CanReboot'             => 'Can Reboot',
     'CanSetPresets'        => 'Can Set Presets',
     'CanSleep'             => 'Can Sleep',
     'CanTilt'              => 'Can Tilt',
@@ -228,7 +229,7 @@ $SLANG = array(
     'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Donate'               => 'Please Donate',
     'DonateAlready'        => 'No, I\'ve already donated',
-    'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
+    'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to https://zoneminder.com/donate/ in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
     'DonateRemindDay'      => 'Not yet, remind again in 1 day',
     'DonateRemindHour'     => 'Not yet, remind again in 1 hour',
     'DonateRemindMonth'    => 'Not yet, remind again in 1 month',
