@@ -20,6 +20,7 @@
 
 // ZoneMinder Russian Translation by Borodin A.S.
 // ZoneMinder Russian Translation updated by IDDQDesnik, 2017
+// ZoneMinder Russian Translation updated by santos995, 2019
 
 // Notes for Translators
 // 0. Get some credit, put your name in the line above (optional)
@@ -76,11 +77,11 @@ $SLANG = array(
     '32BitColour'          => '32 битный цвет',          // Added - 2011-06-15
     '8BitGrey'             => '256 оттенков серого',
     'Action'               => 'Действие', 
-    'Actual'               => 'Actual',                 // Added - 2018-08-30
+    'Actual'               => 'Актуальный',                 // Edited - 2019-03-25
     'AddNewControl'        => 'Добавить новый',
     'AddNewMonitor'        => 'Добавить монитор',
-    'AddNewServer'         => 'Add New Server',         // Added - 2018-08-30
-    'AddNewStorage'        => 'Add New Storage',        // Added - 2018-08-30
+    'AddNewServer'         => 'Добавить новый сервер',         // Edited - 2019-03-25
+    'AddNewStorage'        => 'Добавить новое хранилище',        // Edited - 2019-03-25
     'AddNewUser'           => 'Добавить пользователя',
     'AddNewZone'           => 'Добавить зону',
     'Alarm'                => 'Тревога',
@@ -110,24 +111,24 @@ $SLANG = array(
     'AttrCause'            => 'Причина',
     'AttrDiskBlocks'       => 'Диск, блоки',
     'AttrDiskPercent'      => 'Диск, проценты',
-    'AttrDiskSpace'        => 'Disk Space',             // Added - 2018-08-30
+    'AttrDiskSpace'        => 'Дисковое пространство',             // Edited - 2019-03-24
     'AttrDuration'         => 'Длительность',
-    'AttrEndDate'          => 'End Date',               // Added - 2018-08-30
-    'AttrEndDateTime'      => 'End Date/Time',          // Added - 2018-08-30
-    'AttrEndTime'          => 'End Time',               // Added - 2018-08-30
+    'AttrEndDate'          => 'Дата окончания',               // Edited - 2019-03-24
+    'AttrEndDateTime'      => 'Дата/время окончания',          // Edited - 2019-03-24
+    'AttrEndTime'          => 'Время окончания',               // Edited - 2019-03-24
     'AttrEndWeekday'       => 'End Weekday',            // Added - 2018-08-30
-    'AttrFilterServer'     => 'Server Filter is Running On', // Added - 2018-08-30
+    'AttrFilterServer'     => 'Фильтр для серверов запущен', // Edited - 2019-03-24
     'AttrFrames'           => 'Кол-во кадров',
     'AttrId'               => 'ИД',
     'AttrMaxScore'         => 'Макс. оценка',
     'AttrMonitorId'        => 'ИД Монитора',
     'AttrMonitorName'      => 'Название Монитора',
-    'AttrMonitorServer'    => 'Server Monitor is Running On', // Added - 2018-08-30
+    'AttrMonitorServer'    => 'Монитор серверов запущен', // Edited - 2019-03-24
     'AttrName'             => 'Имя',
     'AttrNotes'            => 'Примечание',
-    'AttrStartDate'        => 'Start Date',             // Added - 2018-08-30
-    'AttrStartDateTime'    => 'Start Date/Time',        // Added - 2018-08-30
-    'AttrStartTime'        => 'Start Time',             // Added - 2018-08-30
+    'AttrStartDate'        => 'Дата начала',             // Edited - 2019-03-24
+    'AttrStartDateTime'    => 'Дата/Время начала',        // Edited - 2019-03-24
+    'AttrStartTime'        => 'Время начала',             // Edited - 2019-03-24
     'AttrStartWeekday'     => 'Start Weekday',          // Added - 2018-08-30
     'AttrStateId'          => 'Run State',              // Added - 2018-08-30
     'AttrStorageArea'      => 'Storage Area',           // Added - 2018-08-30
@@ -170,7 +171,7 @@ $SLANG = array(
     'BadStreamReplayBuffer'=> 'Буфер потока повторного воспроизведения должен быть целочисленным и большим либо равным нулю',
     'BadWarmupCount'       => 'Кол-во кадров разогрева должно быть целочисленным и большим либо равным нулю',
     'BadWebColour'         => 'Цвет отметки должен быть правильным Web-цветом',
-    'BadWebSitePath'       => 'Please enter a complete website url, including the http:// or https:// prefix.', // Added - 2018-08-30
+    'BadWebSitePath'       => 'Пожалуйста, введите полной название сайта url, включая http:// или https:// префикс.', // Edited - 2019-03-24
     'BadWidth'             => 'Неправильная ширина',
     'Bandwidth'            => 'канал',
     'BandwidthHead'        => 'канал', // This is the end of the bandwidth status on the top of the console, different in many language due to phrasing;
@@ -178,9 +179,9 @@ $SLANG = array(
     'BlobSizes'            => 'Размер объектов',
     'Blobs'                => 'Кол-во объектов',
     'Brightness'           => 'Яркость',
-    'Buffer'               => 'Buffer',                 // Added - 2015-04-18
+    'Buffer'               => 'Буфер',                 // Edited - 2019-03-24
     'Buffers'              => 'Буферы',
-    'CSSDescription'       => 'Change the default css for this computer', // Added - 2015-04-18
+    'CSSDescription'       => 'Изменить стандартный CSS для данного компьютера', // Edited - 2019-03-24
     'CanAutoFocus'         => 'Автофокус',
     'CanAutoGain'          => 'Автоусиление',
     'CanAutoIris'          => 'Автодиафрагма',
@@ -206,6 +207,7 @@ $SLANG = array(
     'CanMoveRel'           => 'Относительное перемещение',
     'CanPan'               => 'Панорама' ,
     'CanReset'             => 'Сброс',
+    'CanReboot'            => 'Перезагрузка',  // Added - 2019-03-24
     'CanSetPresets'        => 'Создание предустановок',
     'CanSleep'             => 'Сон',
     'CanTilt'              => 'Наклон',
@@ -224,17 +226,17 @@ $SLANG = array(
     'CaptureHeight'        => 'Размер по Y',
     'CaptureMethod'        => 'Метод захвата',         // Added - 2009-02-08
     'CapturePalette'       => 'Режим захвата',
-    'CaptureResolution'    => 'Capture Resolution',     // Added - 2015-04-18
+    'CaptureResolution'    => 'Разрешение',     // Edited - 2019-03-24
     'CaptureWidth'         => 'Размер по X',
     'Cause'                => 'Причина',
     'CheckMethod'          => 'Метод проверки тревоги',
     'ChooseDetectedCamera' => 'Выберите камеру', // Added - 2009-03-31
     'ChooseFilter'         => 'Выбрать фильтр',
-    'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
+    'ChooseLogFormat'      => 'Выбрать формат лога',    // Edited - 2019-03-25
     'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Выберите предустановку',
     'Clear'                => 'Очистить',                  // Added - 2011-06-16
-    'CloneMonitor'         => 'Clone',                  // Added - 2018-08-30
+    'CloneMonitor'         => 'Клонировать',                  // Edited - 2019-03-25
     'Close'                => 'Закрыть',
     'Colour'               => 'Цвет',
     'Command'              => 'Command',
@@ -248,7 +250,7 @@ $SLANG = array(
     'ConjOr'               => 'или',
     'Console'              => 'Сервер',
     'ContactAdmin'         => 'Пожалуйста обратитесь к вашему администратору.',
-    'Continue'             => 'Continue',
+    'Continue'             => 'Продолжить', // Added - 2019-03-25
     'Contrast'             => 'Контраст',
     'Control'              => 'Управление',
     'ControlAddress'       => 'Адрес устройства',
@@ -262,12 +264,12 @@ $SLANG = array(
     'CycleWatch'           => 'Циклический просмотр',
     'DateTime'             => 'Дата/Время',              // Added - 2011-06-16
     'Day'                  => 'День',
-    'Debug'                => 'Debug',
+    'Debug'                => 'Отладка', // Added - 2019-03-25
     'DefaultRate'          => 'Скорость по умолчанию',
     'DefaultScale'         => 'Масштаб по умолчанию',
     'DefaultView'          => 'Вид по умолчанию',
     'Deinterlacing'        => 'Устранение чересстрочности',          // Added - 2015-04-18
-    'Delay'                => 'Delay',                  // Added - 2015-04-18
+    'Delay'                => 'Задержка',                  // Edited - 2019-03-25
     'Delete'               => 'Удалить',
     'DeleteAndNext'        => 'Удалить &amp; след.',
     'DeleteAndPrev'        => 'Удалить &amp; пред.',
@@ -275,18 +277,18 @@ $SLANG = array(
     'Description'          => 'Описание',
     'DetectedCameras'      => 'Найденные камеры',       // Added - 2009-03-31
     'DetectedProfiles'     => 'Найденные профили',      // Added - 2015-04-18
-    'Device'               => 'Device',                 // Added - 2009-02-08
+    'Device'               => 'Устройство',                 // Edited - 2019-03-25
     'DeviceChannel'        => 'Канал',
     'DeviceFormat'         => 'Формат',
     'DeviceNumber'         => 'Номер устройства',
     'DevicePath'           => 'Путь к устройству',
-    'Devices'              => 'Devices',
+    'Devices'              => 'Устройства', // Edited - 2019-03-25
     'Dimensions'           => 'Размеры',
     'DisableAlarms'        => 'Запретить тревогу',
     'Disk'                 => 'Диск', 
     'Display'              => 'Display',                // Added - 2011-01-30
     'Displaying'           => 'Отображено',             // Added - 2011-06-16
-    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
+    'DoNativeMotionDetection'=> 'Использовать встроенное обнаружение движения', // Edited - 2019-03-25
     'Donate'               => 'Поддержите проект', 
     'DonateAlready'        => 'Нет, я уже сделал пожертвование', 
     'DonateEnticement'     => 'Вы какое-то время используете ZoneMinder и, надеемся, находите его полезным дополнением к вашей домашней или рабочей безопасности. Хотя ZoneMinder есть и будет оставаться свободным и бесплатным, он требует денег на разработку и поддержку. Если Вы хотите поддержать его будущее развитие и новые функции, пожалуйста сделайте пожертвование. Это, конечно, необязательно, но очень высоко ценится. Вы можете пожертвовать любую сумму.<br><br>Если Вы хотите сделать пожертвование, то выберите соответствующий вариант ниже или перейдите по адресу https://www.bountysource.com/teams/zoneminder в вашем браузере.<br><br>Спасибо за использование ZoneMinder, и не забывайте посетить форум на ZoneMinder.com для поддержки и пожеланий как сделать ZoneMinder еще лучше.', 
@@ -297,11 +299,11 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Нет, не сейчас, напомнить через неделю', 
     'DonateYes'            => 'Да, я хотел бы сделать пожертвование', 
     'Download'             => 'Скачать',
-    'DownloadVideo'        => 'Download Video',         // Added - 2018-08-30
-    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
+    'DownloadVideo'        => 'Скачать видео',         // Added - 2019-03-24
+    'DuplicateMonitorName' => 'Скопировать имя монитора', // Added - 2019-03-25
     'Duration'             => 'Длительность',
     'Edit'                 => 'Редактирование',
-    'EditLayout'           => 'Edit Layout',            // Added - 2018-08-30
+    'EditLayout'           => 'Редактирование шаблона',            // Added - 2019-03-25
     'Email'                => 'Email',
     'EnableAlarms'         => 'Разрешить тревогу',
     'Enabled'              => 'Включен',
@@ -312,13 +314,13 @@ $SLANG = array(
     'Etc'                  => 'и т.д.',
     'Event'                => 'Событие',
     'EventFilter'          => 'Фильтр событий',
-    'EventId'              => 'Event Id',
-    'EventName'            => 'Event Name',
+    'EventId'              => 'Id события', // Added - 2019-03-25
+    'EventName'            => 'Имя события', // Added - 2019-03-25
     'EventPrefix'          => 'Префикс события',
     'Events'               => 'События',
     'Exclude'              => 'Исключить',
     'Execute'              => 'Выполнить',
-    'Exif'                 => 'Embed EXIF data into image', // Added - 2018-08-30
+    'Exif'                 => 'Включить EXIF информацию в изображение', // Added - 2019-03-24
     'Export'               => 'Экспорт',
     'ExportDetails'        => 'Экспортировать описание события',
     'ExportFailed'         => 'Ошибка экспорта',
@@ -350,14 +352,14 @@ $SLANG = array(
     'FilterMessageEvents'  => 'Message details of all matches',
     'FilterMoveEvents'     => 'Move all matches',       // Added - 2018-08-30
     'FilterPx'             => 'Пкс фильтра',
-    'FilterUnset'          => 'You must specify a filter width and height',
-    'FilterUpdateDiskSpace'=> 'Update used disk space', // Added - 2018-08-30
-    'FilterUploadEvents'   => 'Upload all matches',
-    'FilterVideoEvents'    => 'Create video for all matches',
+    'FilterUnset'          => 'Вы должны указать ширину и высоту фильтра', // Added - 2019-03-25
+    'FilterUpdateDiskSpace'=> 'Обновить используемое дисковое пространство', // Edited - 2019-03-25
+    'FilterUploadEvents'   => 'Загрузить все совпадения', // Added - 2019-03-25
+    'FilterVideoEvents'    => 'Создать видео для всех совпадений', // Added - 2019-03-25
     'Filters'              => 'Фильтры',
     'First'                => 'Первый',
-    'FlippedHori'          => 'Flipped Horizontally',
-    'FlippedVert'          => 'Flipped Vertically',
+    'FlippedHori'          => 'Перевернутый горизонтально', // Added - 2019-03-25
+    'FlippedVert'          => 'Перевернутый вертикально', // Added - 2019-03-25
     'FnMocord'             => 'Mocord',            // Added 2013.08.16.
     'FnModect'             => 'Modect',            // Added 2013.08.16.
     'FnMonitor'            => 'Monitor',            // Added 2013.08.16.
@@ -376,7 +378,7 @@ $SLANG = array(
     'Function'             => 'Функция',
     'Gain'                 => 'Gain',
     'General'              => 'Основные',
-    'GenerateDownload'     => 'Generate Download',      // Added - 2018-08-30
+    'GenerateDownload'     => 'Сгенерировать загрузку',      // Edited - 2019-03-25
     'GenerateVideo'        => 'Генерировать видео',
     'GeneratingVideo'      => 'Генерируется видео',
     'GoToZoneMinder'       => 'Перейти на ZoneMinder.com',
@@ -397,7 +399,7 @@ $SLANG = array(
     'High'                 => 'широкий',
     'HighBW'               => 'Широкий канал',
     'Home'                 => 'Домой',
-    'Hostname'             => 'Hostname',               // Added - 2018-08-30
+    'Hostname'             => 'Имя хоста',               // Edited - 2019-03-25
     'Hour'                 => 'Час',
     'Hue'                  => 'Оттенок',
     'Id'                   => 'ИД',
@@ -405,13 +407,13 @@ $SLANG = array(
     'Ignore'               => 'Игнорировать',
     'Image'                => 'Изображение',
     'ImageBufferSize'      => 'Буфер изображений',
-    'Images'               => 'Images',
+    'Images'               => 'Изображения', // Added - 2019-03-25
     'In'                   => 'In',
     'Include'              => 'Включить',
     'Inverted'             => 'Инвертировать',
     'Iris'                 => 'Наклон',
     'KeyString'            => 'Key String',
-    'Label'                => 'Label',
+    'Label'                => 'Имя', // Added - 2019-03-25
     'Language'             => 'Язык',
     'Last'                 => 'Последний',
     'Layout'               => 'Раскладка',                 // Added - 2009-02-08
@@ -422,16 +424,16 @@ $SLANG = array(
     'Line'                 => 'Строка',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Привязанные мониторы',
     'List'                 => 'Список',
-    'ListMatches'          => 'List Matches',           // Added - 2018-08-30
+    'ListMatches'          => 'Список совпадений',           // Edited - 2019-03-25
     'Load'                 => 'Нагрузка', 
     'Local'                => 'Локальный',
     'Log'                  => 'Лог',                    // Added - 2011-06-16;
     'LoggedInAs'           => 'Пользователь',
-    'Logging'              => 'Logging',                // Added - 2011-06-16
+    'Logging'              => 'Логгирование',                // Added - 2019-03-24
     'LoggingIn'            => 'Вход в систему',
     'Login'                => 'Войти',
     'Logout'               => 'Выйти',
-    'Logs'                 => 'Logs',                   // Added - 2011-06-17
+    'Logs'                 => 'Логи',                   // Added - 2019-03-24
     'Low'                  => 'узкий',
     'LowBW'                => 'Узкий канал',
     'Main'                 => 'Основные',
@@ -439,7 +441,7 @@ $SLANG = array(
     'Manual'               => 'Manual',
     'Mark'                 => 'Метка',
     'Max'                  => 'Макс.',
-    'MaxBandwidth'         => 'Max Bandwidth',
+    'MaxBandwidth'         => 'Макс. пропускная способность', // Added - 2019-03-25
     'MaxBrScore'           => 'Макс.<br/>оценка',
     'MaxFocusRange'        => 'Макс. диап. фокуса',
     'MaxFocusSpeed'        => 'Макс. скор. фокуса',
@@ -509,7 +511,7 @@ $SLANG = array(
     'MonitorProbeIntro'    => 'В этом списке показаны найденные аналоговые и сетевые камеры, как уже заведенные, так и доступные для выбора.<br/><br/>Выберите нужную из списка ниже.<br/><br/>Обратите внимание, что не все камеры могут быть найдены, и что выбор камеры может переписать настройки определенные для этого монитора.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Мониторы',
     'Montage'              => 'Монтаж', 
-    'MontageReview'        => 'Montage Review',         // Added - 2018-08-30
+    'MontageReview'        => 'Обзор монтажа',         // Added - 2019-03-24
     'Month'                => 'Месяц',
     'More'                 => 'Еще',                   // Added - 2011-06-16
     'MotionFrameSkip'      => 'Кол-во пропуск. кадров движения',
@@ -529,16 +531,16 @@ $SLANG = array(
     'Network'              => 'Сеть',
     'New'                  => 'Нов.',
     'NewGroup'             => 'Новая группа',
-    'NewLabel'             => 'New Label',
+    'NewLabel'             => 'Новое имя', // Added - 2019-03-25
     'NewPassword'          => 'Новый пароль',
     'NewState'             => 'Новое состояние',
     'NewUser'              => 'Новый пользователь',
     'Next'                 => 'След.',
     'No'                   => 'Нет',
-    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
-    'NoDetectedProfiles'   => 'No Detected Profiles',   // Added - 2018-08-30
+    'NoDetectedCameras'    => 'Нет камер',    // Added - 2019-03-24
+    'NoDetectedProfiles'   => 'Нет профилей',   // Added - 2019-03-24
     'NoFramesRecorded'     => 'Это событие не содержит кадров',
-    'NoGroup'              => 'No Group',
+    'NoGroup'              => 'Нет группы',   // Added - 2019-03-24
     'NoSavedFilters'       => 'нет сохраненных фильтров',
     'NoStatisticsRecorded' => 'Статистика по этому событию/кадру не записана',
     'None'                 => 'отсутствует',
@@ -546,8 +548,8 @@ $SLANG = array(
     'Normal'               => 'Нормальная',
     'Notes'                => 'Примечание',
     'NumPresets'           => 'Кол-во предустановок',
-    'Off'                  => 'Off',
-    'On'                   => 'On',
+    'Off'                  => 'Выкл.', // Added - 2019-03-25
+    'On'                   => 'Вкл.', // Added - 2019-03-25
     'OnvifCredentialsIntro'=> 'Пожалуйста укажите имя пользователя и пароль для выбранной камеры.<br/><br/>Если пользователь для камеры не был создан, тогда будет создан новый с указанными данными.<br/><br/>', // Added - 2015-04-18
     'OnvifProbe'           => 'ONVIF',                  // Added - 2015-04-18
     'OnvifProbeIntro'      => 'В этом списке показаны найденные ONVIF камеры, как уже заведенные, так и доступные для выбора.<br/><br/>Выберите нужную из списка ниже.<br/><br/>Обратите внимание, что не все камеры могут быть найдены, и что выбор камеры может переписать настройки определенные для этого монитора.<br/><br/>', // Added - 2015-04-18
@@ -566,7 +568,7 @@ $SLANG = array(
     'Open'                 => 'Открыть',
     'OptionHelp'           => 'Справка',
     'OptionRestartWarning' => 'Эти изменения подействуют только после перезапуска программы.',
-    'OptionalEncoderParam' => 'Optional Encoder Parameters', // Added - 2018-08-30
+    'OptionalEncoderParam' => 'Необязательные параметры кодировщика', // Added - 2019-03-24
     'Options'              => 'Опции',
     'OrEnterNewName'       => 'или введите новое имя',
     'Order'                => 'Сортировка',
@@ -591,7 +593,7 @@ $SLANG = array(
     'Play'                 => 'Играть',
     'PlayAll'              => 'Воспр. все',
     'PleaseWait'           => 'Пожалуйста подождите',
-    'Plugins'              => 'Plugins',
+    'Plugins'              => 'Плагины',   // Edited - 2019-03-24
     'Point'                => 'Точка',
     'PostEventImageBuffer' => 'Буфер после события',
     'PreEventImageBuffer'  => 'Буфер до события',
@@ -604,13 +606,13 @@ $SLANG = array(
     'ProfileProbeIntro'    => 'В этом списке показаны существующие профили потока выбранной камеры.<br/><br/>Выберите нужный из списка ниже.<br/><br/>Обратите внимание, что ZoneMinder не может добавить дополнительный профиль, и что выбор профиля может переписать настройки определенные для этого монитора.<br/><br/>', // Added - 2015-04-18
     'Progress'             => 'Прогресс',               // Added - 2015-04-18
     'Protocol'             => 'Протокол',
-    'RTSPDescribe'         => 'Use RTSP Response Media URL', // Added - 2018-08-30
-    'RTSPTransport'        => 'RTSP Transport Protocol', // Added - 2018-08-30
+    'RTSPDescribe'         => 'Использовать RTSP URL для ответа', // Edited - 2019-03-25
+    'RTSPTransport'        => 'Транспортный протокол RTSP', // Edited - 2019-03-25
     'Rate'                 => 'Скорость',
     'Real'                 => 'Реальная',
     'RecaptchaWarning'     => 'Your reCaptcha secret key is invalid. Please correct it, or reCaptcha will not work', // Added - 2018-08-30
     'Record'               => 'Record',
-    'RecordAudio'          => 'Whether to store the audio stream when saving an event.', // Added - 2018-08-30
+    'RecordAudio'          => 'Сохранять ли аудиопоток при сохранении события.', // Edited - 2019-03-25
     'RefImageBlendPct'     => 'Смешение опорного кадра, %',
     'Refresh'              => 'Обновить',
     'Remote'               => 'Удаленный',
@@ -626,7 +628,7 @@ $SLANG = array(
     'ReplayAll'            => 'Все события',
     'ReplayGapless'        => 'События подряд',
     'ReplaySingle'         => 'Одно событие',
-    'ReportEventAudit'     => 'Audit Events Report',    // Added - 2018-08-30
+    'ReportEventAudit'     => 'Отчёт о событиях аудита',    // Edited - 2019-03-24
     'Reset'                => 'Сбросить',
     'ResetEventCounts'     => 'Обнулить счетчик событий',
     'Restart'              => 'Перезапустить',
@@ -638,14 +640,14 @@ $SLANG = array(
     'Rewind'               => 'Назад',
     'RotateLeft'           => 'Повернуть влево',
     'RotateRight'          => 'Повернуть вправо',
-    'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
+    'RunLocalUpdate'       => 'Запустите zmupdate.pl для обновления', // Edited - 2019-03-24
     'RunMode'              => 'Режим работы',
     'RunState'             => 'Состояние',
     'Running'              => 'Выполняется',
     'Save'                 => 'Сохранить',
     'SaveAs'               => 'Сохранить как',
     'SaveFilter'           => 'Сохранить фильтр',
-    'SaveJPEGs'            => 'Save JPEGs',             // Added - 2018-08-30
+    'SaveJPEGs'            => 'Сохранить JPEG-и',             // Edited - 2019-03-24
     'Scale'                => 'Масштаб',
     'Score'                => 'Оценка',
     'Secs'                 => 'Сек.',
@@ -653,46 +655,46 @@ $SLANG = array(
     'Select'               => 'Выбор',
     'SelectFormat'         => 'Выберите формат',          // Added - 2011-06-17
     'SelectLog'            => 'Выберите лог',             // Added - 2011-06-17
-    'SelectMonitors'       => 'Select Monitors',
+    'SelectMonitors'       => 'Выбрать Мониторы',   //  Edited - 2019-03-24
     'SelfIntersecting'     => 'Polygon edges must not intersect',
-    'Set'                  => 'Set',
+    'Set'                  => 'Установка',  // Edited - 2019-03-24
     'SetNewBandwidth'      => 'Установка новой ширина канала',
-    'SetPreset'            => 'Set Preset',
+    'SetPreset'            => 'Установка пресета',  // Edited - 2019-03-24
     'Settings'             => 'Настройки',
     'ShowFilterWindow'     => 'Показать окно фильтра',
     'ShowTimeline'         => 'Показать график',
     'SignalCheckColour'    => 'Цвет проверки сигнала',
     'SignalCheckPoints'    => 'Signal Check Points',    // Added - 2018-08-30
-    'Size'                 => 'Size',
-    'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
+    'Size'                 => 'Размер',  // Edited - 2019-03-24
+    'SkinDescription'      => 'Смена стандартного скина для данного компьютера', // Edited - 2019-03-24
     'Sleep'                => 'Sleep',
     'SortAsc'              => 'По возр.',
     'SortBy'               => 'Сортировать',
     'SortDesc'             => 'По убыв.',
     'Source'               => 'Источник',
-    'SourceColours'        => 'Source Colours',         // Added - 2009-02-08
+    'SourceColours'        => 'Цвета источника',         // Edited - 2019-03-24
     'SourcePath'           => 'Путь к источнику',            // Added - 2009-02-08
     'SourceType'           => 'Тип источника',
-    'Speed'                => 'Speed',
-    'SpeedHigh'            => 'High Speed',
-    'SpeedLow'             => 'Low Speed',
-    'SpeedMedium'          => 'Medium Speed',
-    'SpeedTurbo'           => 'Turbo Speed',
+    'Speed'                => 'Скорость',  //Edited - 2019-03-24
+    'SpeedHigh'            => 'Высокая скорость',  //Edited - 2019-03-24
+    'SpeedLow'             => 'Низкая скорость',  //Edited - 2019-03-24
+    'SpeedMedium'          => 'Средняя скорость',
+    'SpeedTurbo'           => 'Максимальная скорость', // Edited - 2019-03-24
     'Start'                => 'Запустить',
     'State'                => 'Состояние',
     'Stats'                => 'Статистика',
     'Status'               => 'Статус',
-    'StatusConnected'      => 'Capturing',              // Added - 2018-08-30
-    'StatusNotRunning'     => 'Not Running',            // Added - 2018-08-30
-    'StatusRunning'        => 'Not Capturing',          // Added - 2018-08-30
-    'StatusUnknown'        => 'Unknown',                // Added - 2018-08-30
+    'StatusConnected'      => 'Записывается',              // Edited - 2019-03-25
+    'StatusNotRunning'     => 'Не запущен',            // Edited - 2019-03-25
+    'StatusRunning'        => 'Не записывается',          // Edited - 2019-03-25
+    'StatusUnknown'        => 'Неизвестно',                // Edited - 2019-03-25
     'Step'                 => 'Шаг',
     'StepBack'             => 'Кадр назад',
     'StepForward'          => 'Кадр вперед',
-    'StepLarge'            => 'Large Step',
-    'StepMedium'           => 'Medium Step',
-    'StepNone'             => 'No Step',
-    'StepSmall'            => 'Small Step',
+    'StepLarge'            => 'Большой шаг', // Added - 2019-03-25
+    'StepMedium'           => 'Средний шаг', // Added - 2019-03-25
+    'StepNone'             => 'Без шагов', // Added - 2019-03-25
+    'StepSmall'            => 'Малый шаг', // Added - 2019-03-25
     'Stills'               => 'Стоп-кадры',
     'Stop'                 => 'Остановить',
     'Stopped'              => 'Остановлен',
@@ -757,24 +759,24 @@ $SLANG = array(
     'VersionRemindNever'   => 'Не говорить о новых версиях',
     'VersionRemindWeek'    => 'Напомнить через неделю',
     'Video'                => 'Видео',
-    'VideoFormat'          => 'Video Format',
+    'VideoFormat'          => 'Формат видео', // Edited - 2019-03-24
     'VideoGenFailed'       => 'Ошибка генерации видео!',
     'VideoGenFiles'        => 'Existing Video Files',
-    'VideoGenNoFiles'      => 'No Video Files Found',
+    'VideoGenNoFiles'      => 'Видео не найдено',  // Edited - 2019-03-24
     'VideoGenParms'        => 'Параметры генерации видео',
-    'VideoGenSucceeded'    => 'Video Generation Succeeded!',
+    'VideoGenSucceeded'    => 'Видео сгенерировано!', // Edited - 2019-03-24
     'VideoSize'            => 'Размер изображения',
     'VideoWriter'          => 'Video Writer',           // Added - 2018-08-30
     'View'                 => 'Просмотр',
     'ViewAll'              => 'Просм. все',
-    'ViewEvent'            => 'View Event',
+    'ViewEvent'            => 'Просм. событие',  // Edited - 2019-03-24
     'ViewPaged'            => 'Просм. постранично',
     'Wake'                 => 'Wake',
     'WarmupFrames'         => 'Кадры разогрева',
     'Watch'                => 'Watch',
     'Web'                  => 'Интерфейс',
     'WebColour'            => 'Цвет отметки',
-    'WebSiteUrl'           => 'Website URL',            // Added - 2018-08-30
+    'WebSiteUrl'           => 'URL сайта',            // Edited - 2019-03-25
     'Week'                 => 'Неделя',
     'White'                => 'Бал. белого',
     'WhiteBalance'         => 'White Balance',
@@ -797,7 +799,7 @@ $SLANG = array(
     'ZoneMinMaxBlobs'      => 'Мин/Макс кол-во объектов',
     'ZoneMinMaxFiltArea'   => 'Мин/Макс разм. фильтр. зоны ',
     'ZoneMinMaxPixelThres' => 'Мин/Макс порог изм. пикс. (0-255)',
-    'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
+    'ZoneMinderLog'        => 'Лог ZoneMinder',         // Edited - 2019-03-25
     'ZoneOverloadFrames'   => 'Кол-во игнор. кадров перегрузки',
     'Zones'                => 'Зоны',
     'Zoom'                 => 'Увеличение',
