@@ -206,6 +206,7 @@ $SLANG = array(
     'CanMoveRel'           => 'Har relativ förflyttning',
     'CanPan'               => 'Har panorering',
     'CanReset'             => 'Har återställning',
+	'CanReboot'             => 'Can Reboot',
     'CanSetPresets'        => 'Har förinställningar',
     'CanSleep'             => 'Kan vila',
     'CanTilt'              => 'Kan tilta',
@@ -289,7 +290,7 @@ $SLANG = array(
     'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Donate'               => 'Var vänlig och donera',
     'DonateAlready'        => 'Nej, Jag har redan donerat',
-    'DonateEnticement'     => 'Du har kört ZoneMinder ett tag nu och förhoppningsvis har du sett att det fungerar bra hemma eller på ditt företag. Även om ZoneMinder är, och kommer att vara, fri programvara och öppen kallkod, så kostar det pengar att utveckla och underhålla. Om du vill hjälpa till med framtida utveckling och nya funktioner så var vanlig och bidrag med en slant. Bidragen är naturligtvis en option men mycket uppskattade och du kan bidra med precis hur mycket du vill.<br><br>Om du vill ge ett bidrag väljer du nedan eller surfar till http://www.zoneminder.com/donate.html.<br><br>Tack för att du använder ZoneMinder, glöm inte att besöka forumen på ZoneMinder.com för support och förslag om hur du får din ZoneMinder att fungera lite bättre.',
+    'DonateEnticement'     => 'Du har kört ZoneMinder ett tag nu och förhoppningsvis har du sett att det fungerar bra hemma eller på ditt företag. Även om ZoneMinder är, och kommer att vara, fri programvara och öppen kallkod, så kostar det pengar att utveckla och underhålla. Om du vill hjälpa till med framtida utveckling och nya funktioner så var vanlig och bidrag med en slant. Bidragen är naturligtvis en option men mycket uppskattade och du kan bidra med precis hur mycket du vill.<br><br>Om du vill ge ett bidrag väljer du nedan eller surfar till https://zoneminder.com/donate/.<br><br>Tack för att du använder ZoneMinder, glöm inte att besöka forumen på ZoneMinder.com för support och förslag om hur du får din ZoneMinder att fungera lite bättre.',
     'DonateRemindDay'      => 'Inte än, påminn om 1 dag',
     'DonateRemindHour'     => 'Inte än, påminn om en 1 timme',
     'DonateRemindMonth'    => 'Inte än, påminn om 1 månad',
