@@ -19,15 +19,23 @@
 //
 
 $rates = array(
-    '10000' => '100x',
-    '5000' => '50x',
-    '2500' => '25x',
-    '1000' => '10x',
-    '400' => '4x',
-    '200' => '2x',
-    '100' => translate('Real'),
-    '50' => '1/2x',
-    '25' => '1/4x',
+  -5000 => '-50x',
+  -2500 => '-25x',
+  -1000 => '-10x',
+  -500  => '-5x',
+  -200  => '-2x',
+  -100  => '-1x',
+  -50   => '-1/2x',
+  -25   => '-1/4x',
+  0     => translate('Stop'),
+  25    => '1/4x',
+  50    => '1/2x',
+  100   => '1x',
+  200   => '2x',
+  500   => '5x',
+  1000  => '10x',
+  2500  => '25x',
+  5000  => '50x'
 );
 
 $scales = array(
