@@ -24,9 +24,9 @@ if ( !canEdit('Groups') ) {
 }
 
 if ( !empty($_REQUEST['gid']) ) {
-  $newGroup = new Group($_REQUEST['gid']);
+  $newGroup = new ZM\Group($_REQUEST['gid']);
 } else {
-  $newGroup = new Group();
+  $newGroup = new ZM\Group();
 }
 
 xhtmlHeaders(__FILE__, translate('Group').' - '.$newGroup->Name());
@@ -34,25 +34,24 @@ xhtmlHeaders(__FILE__, translate('Group').' - '.$newGroup->Name());
 <body>
   <div id="page">
     <div id="header">
-      <h2><?php echo translate('Group') ?> - <?php echo $newGroup->Name() ?></h2>
+      <h2><?php echo translate('Group') ?> - <?php echo validHtmlStr($newGroup->Name()); ?></h2>
     </div>
     <div id="content">
-      <form name="groupForm" method="post" action="<?php echo $_SERVER['PHP_SELF'] ?>">
+      <form id="groupForm" name="groupForm" method="post" action="?">
         <input type="hidden" name="view" value="<?php echo $view ?>"/>
-        <input type="hidden" name="action" value="group"/>
         <input type="hidden" name="gid" value="<?php echo $newGroup->Id() ?>"/>
         <table id="contentTable" class="major">
           <tbody>
             <tr>
               <th scope="row"><?php echo translate('Name') ?></th>
-              <td><input type="text" name="newGroup[Name]" value="<?php echo validHtmlStr($newGroup->Name()) ?>" oninput="configureButtons(this);"/></td>
+              <td><input type="text" name="newGroup[Name]" value="<?php echo validHtmlStr($newGroup->Name()) ?>" data-on-input="configureButtons"/></td>
             </tr>
             <tr>
               <th scope="row"><?php echo translate('ParentGroup') ?></th>
               <td>
 <?php
 $Groups = array();
-foreach ( Group::find() as $Group ) {
+foreach ( ZM\Group::find() as $Group ) {
   $Groups[$Group->Id()] = $Group;
 }
 
@@ -89,19 +88,19 @@ function get_children($Group) {
 $kids = get_children($newGroup);
 if ( $newGroup->Id() )
   $kids[] = $newGroup->Id();
-$sql = 'SELECT Id,Name from Groups'.(count($kids)?' WHERE Id NOT IN ('.implode(',',array_map(function(){return '?';}, $kids)).')' : '').' ORDER BY Name';
+$sql = 'SELECT Id,Name FROM `Groups`'.(count($kids)?' WHERE Id NOT IN ('.implode(',',array_map(function(){return '?';}, $kids)).')' : '').' ORDER BY Name';
 $options = array(''=>'None');
 foreach ( dbFetchAll($sql, null, $kids) as $option ) {
   $options[$option['Id']] = str_repeat('&nbsp;&nbsp;', $Groups[$option['Id']]->depth()) . $option['Name'];
 }
-echo htmlSelect('newGroup[ParentId]', $options, $newGroup->ParentId(), array('onchange'=>'configureButtons(this);'));
+echo htmlSelect('newGroup[ParentId]', $options, $newGroup->ParentId(), array('data-on-change'=>'configureButtons'));
 ?>
               </td>
             </tr>
             <tr>
               <th scope="row"><?php echo translate('Monitor') ?></th>
               <td>
-                <select name="newGroup[MonitorIds][]" class="chosen" multiple="multiple" onchange="configureButtons(this);">
+                <select name="newGroup[MonitorIds][]" class="chosen" multiple="multiple" data-on-change="configureButtons">
 <?php
   $monitors = dbFetchAll('SELECT Id,Name FROM Monitors ORDER BY Sequence ASC');
   $monitorIds = $newGroup->MonitorIds();
@@ -119,16 +118,14 @@ echo htmlSelect('newGroup[ParentId]', $options, $newGroup->ParentId(), array('on
           </tbody>
         </table>
         <div id="contentButtons">
-          <button type="submit" name="saveBtn" value="Save"<?php $newGroup->Id() ? '' : ' disabled="disabled"'?>>
+          <button type="submit" name="action" value="Save"<?php $newGroup->Id() ? '' : ' disabled="disabled"'?>>
           <?php echo translate('Save') ?>
           </button>
-          <input type="button" value="<?php echo translate('Cancel') ?>" onclick="closeWindow()"/>
+          <button type="button" data-on-click="closeWindow"><?php echo translate('Cancel') ?></button>
         </div>
       </form>
     </div>
   </div>
+  <script nonce="<?php echo $cspNonce;?>">$j('.chosen').chosen();</script>
 </body>
-  <script type="text/javascript">
-  $j('.chosen').chosen();
-  </script>
 </html>
