@@ -175,12 +175,7 @@ function changeScale() {
   } else {
     alarmCue.html(renderAlarmCues(eventViewer));//just re-render alarmCues.  skip ajax call
   }
-  if ( scale = '0' || scale == 'auto' ) {
-    Cookie.write('zmEventScaleAuto', 'auto', {duration: 10*365});
-  } else {
-    Cookie.write('zmEventScale'+eventData.MonitorId, scale, {duration: 10*365});
-    Cookie.dispose('zmEventScaleAuto');
-  }
+  Cookie.write('zmEventScale'+eventData.MonitorId, scale, {duration: 10*365});
 }
 
 function changeReplayMode() {
@@ -208,10 +203,14 @@ function changeRate() {
           vid.currentTime(vid.currentTime() - (revSpeed/2)); //Half of reverse speed because our interval is 500ms.
         }
       }, 500); //500ms is a compromise between smooth reverse and realistic performance
+    } else {
+      streamReq.send(streamParms+"&command="+CMD_VARPLAY+"&rate="+rate);
     } // end if vid
   } else { // Forward rate
     if ( vid ) {
       vid.playbackRate(rate/100);
+    } else {
+      streamReq.send(streamParms+"&command="+CMD_VARPLAY+"&rate="+rate);
     }
   }
   Cookie.write('zmEventRate', rate, {duration: 10*365});
@@ -243,7 +242,11 @@ function getCmdResponse( respObj, respText ) {
   }
 
   streamStatus = respObj.status;
-  if ( streamStatus.progress >= Math.round(parseFloat(eventData.Length)) ) {
+  if ( streamStatus.duration && ( streamStatus.duration != parseFloat(eventData.Length) ) ) {
+    eventData.Length = streamStatus.duration;
+  }
+  if ( streamStatus.progress > parseFloat(eventData.Length) ) {
+    console.log("Limiting progress to " + streamStatus.progress + ' >= ' + parseFloat(eventData.Length) );
     streamStatus.progress = parseFloat(eventData.Length);
   } //Limit progress to reality
 
@@ -262,7 +265,6 @@ function getCmdResponse( respObj, respText ) {
   if ( streamStatus.paused == true ) {
     streamPause( );
   } else {
-    console.log('streamStatus.rate: ' + streamStatus.rate);
     $j('select[name="rate"]').val(streamStatus.rate*100);
     Cookie.write('zmEventRate', streamStatus.rate*100, {duration: 10*365});
     streamPlay( );
@@ -286,7 +288,7 @@ function getCmdResponse( respObj, respText ) {
   } // end if haev a new auth hash
 
   streamCmdTimer = streamQuery.delay( streamTimeout ); //Timeout is refresh rate for progressBox and time display
-}
+} // end function getCmdResponse( respObj, respText )
 
 var streamReq = new Request.JSON( {
   url: monitorUrl,
