@@ -1,4 +1,4 @@
-window.addEvent( 'domready', function() {
+window.addEventListener( 'DOMContentLoaded', function() {
   if ( failed == true ) {
     $('loginError').removeClass( 'hidden' );
   }
