@@ -10,39 +10,31 @@ var controlOptions = new Object();
   $controlTypes = array( ''=>translate('None') );
   # Temporary workaround to show all ptz control types regardless of monitor source type
   #    $sql = "select * from Controls where Type = '".$newMonitor['Type']."'";
-  $sql = "select * from Controls";
-  foreach( dbFetchAll( $sql ) as $row ) {
+  $sql = 'SELECT `Id`,`Name`,`HasHomePreset`,`NumPresets` FROM `Controls` ORDER BY lower(`Name`)';
+  foreach( dbFetchAll($sql) as $row ) {
     $controlTypes[$row['Id']] = $row['Name'];
-?>
-controlOptions[<?php echo $row['Id'] ?>] = new Array();
-<?php
-    if ( $row['HasHomePreset'] ) {
-?>
-controlOptions[<?php echo $row['Id'] ?>][0] = '<?php echo translate('Home') ?>';
-<?php
-    } else {
-?>
-controlOptions[<?php echo $row['Id'] ?>][0] = null;
-<?php
-    }
+    echo '
+controlOptions['.$row['Id'].'] = new Array();
+controlOptions['.$row['Id'].'][0] = '.
+    ( $row['HasHomePreset'] ? '\''.translate('Home').'\'' : 'null' ).'
+';
     for ( $i = 1; $i <= $row['NumPresets']; $i++ ) {
-?>
-controlOptions[<?php echo $row['Id'] ?>][<?php echo $i ?>] = '<?php echo translate('Preset').' '.$i ?>';
-<?php
+      echo 'controlOptions['. $row['Id'].']['.$i.'] = \''.translate('Preset').' '.$i .'\';
+';
     }
-  }
-}
+  } # end foreach row
+} # end if ZM_OPT_CONTROL
 ?>
 
 var monitorNames = new Object();
 <?php
 $query = empty($_REQUEST['mid']) ? dbQuery('SELECT Name FROM Monitors') : dbQuery('SELECT Name FROM Monitors WHERE Id != ?', array($_REQUEST['mid']) );
 if ( $query ) {
-while ( $name = dbFetchNext($query, 'Name') ) {
-?>
-monitorNames['<?php echo validJsStr($name) ?>'] = true;
-<?php
-} // end foreach
+  while ( $name = dbFetchNext($query, 'Name') ) {
+    echo '
+monitorNames[\''.validJsStr($name).'\'] = true;
+';
+  } // end foreach
 } # end if query
 ?>
 
@@ -70,6 +62,11 @@ function validateForm( form ) {
       errors[errors.length] = "<?php echo translate('BadPort') ?>";
     //if ( !form.elements['newMonitor[Path]'].value )
       //errors[errors.length] = "<?php echo translate('BadPath') ?>";
+  } else if ( form.elements['newMonitor[Type]'].value == 'Ffmpeg' ) {
+    if ( !form.elements['newMonitor[Path]'].value )
+//|| !form.elements['newMonitor[Path]'].value.match( /^\d+$/ ) ) // valid url
+      errors[errors.length] = "<?php echo translate('BadPath') ?>";
+
   } else if ( form.elements['newMonitor[Type]'].value == 'File' ) {
     if ( !form.elements['newMonitor[Path]'].value )
       errors[errors.length] = "<?php echo translate('BadPath') ?>";
@@ -132,22 +129,26 @@ function validateForm( form ) {
   }
 
   if ( errors.length ) {
-    alert( errors.join( "\n" ) );
-    return( false );
+    alert(errors.join("\n"));
+    return false;
   }
-  return( true );
+
+  var warnings = new Array();
+  if ( (form.elements['newMonitor[Function]'].value != 'Monitor') && (form.elements['newMonitor[Function]'].value != 'None') ) {
+    if ( (form.elements['newMonitor[SaveJPEGs]'].value == '0') && (form.elements['newMonitor[VideoWriter]'].value == '0') ) {
+      warnings[warnings.length] = "<?php echo translate('BadNoSaveJPEGsOrVideoWriter'); ?>";
+    }
+  }
+  if ( warnings.length ) {
+    if ( !confirm(warnings.join("\n")) ) {
+      return false;
+    }
+  }
+
+  return true;
 }
 
-function updateLinkedMonitors( element ) {
-  var form = element.form;
-  var monitorIds = new Array();
-  for ( var i = 0; i < element.options.length; i++ )
-    if ( element.options[i].selected )
-      monitorIds[monitorIds.length] = element.options[i].value;
-  form.elements['newMonitor[LinkedMonitors]'].value = monitorIds.join( ',' );
-}
-
-function updateMethods( element ) {
+function updateMethods(element) {
   var form = element.form;
 
   var origMethod = form.elements['origMethod'];
@@ -155,31 +156,27 @@ function updateMethods( element ) {
   methodSelector.options.length = 0;
   switch ( element.value ) {
     case 'http' :
-      {
-        <?php
-          foreach( $httpMethods as $value=>$label ) {
-            ?>
-              methodSelector.options[methodSelector.options.length] = new Option( "<?php echo htmlspecialchars($label) ?>", "<?php echo $value ?>" );
-            if ( origMethod.value == "<?php echo $value ?>" )
-              methodSelector.selectedIndex = methodSelector.options.length-1;
-            <?php
-          }
-        ?>
+      <?php
+        foreach( $httpMethods as $value=>$label ) {
+          ?>
+            methodSelector.options[methodSelector.options.length] = new Option("<?php echo htmlspecialchars($label) ?>", "<?php echo $value ?>");
+          if ( origMethod.value == "<?php echo $value ?>" )
+            methodSelector.selectedIndex = methodSelector.options.length-1;
+          <?php
+        }
+      ?>
           break;
-      }
     case 'rtsp' :
-      {
-        <?php
-          foreach( $rtspMethods as $value=>$label ) {
-            ?>
-              methodSelector.options[methodSelector.options.length] = new Option( "<?php echo htmlspecialchars($label) ?>", "<?php echo $value ?>" );
-            if ( origMethod.value == "<?php echo $value ?>" )
-              methodSelector.selectedIndex = form.elements['newMonitor[Method]'].options.length-1;
-            <?php
-          }
-        ?>
-          break;
-      }
+      <?php
+        foreach( $rtspMethods as $value=>$label ) {
+          ?>
+            methodSelector.options[methodSelector.options.length] = new Option( "<?php echo htmlspecialchars($label) ?>", "<?php echo $value ?>" );
+          if ( origMethod.value == "<?php echo $value ?>" )
+            methodSelector.selectedIndex = form.elements['newMonitor[Method]'].options.length-1;
+          <?php
+        }
+      ?>
+    break;
   }
-  return( true );
+  return true;
 }
