@@ -1,4 +1,4 @@
-var eventId = '<?php echo $event['Id'] ?>';
+var eventId = '<?php echo $event->Id() ?>';
 
 var videoGenSuccessString = '<?php echo addslashes(translate('VideoGenSucceeded')) ?>';
 var videoGenFailedString = '<?php echo addslashes(translate('VideoGenFailed')) ?>';
