@@ -23,7 +23,7 @@ if ( !canEdit('System') ) {
   return;
 }
 
-$Server = new Server($_REQUEST['id']);
+$Server = new ZM\Server($_REQUEST['id']);
 if ( $_REQUEST['id'] and ! $Server->Id() ) {
   $view = 'error';
   return;
@@ -39,7 +39,7 @@ xhtmlHeaders(__FILE__, translate('Server').' - '.$Server->Name());
       <h2><?php echo translate('Server').' - '.$Server->Name() ?></h2>
     </div>
     <div id="content">
-      <form name="contentForm" method="post" action="<?php echo $_SERVER['PHP_SELF'] ?>" onsubmit="return validateForm(this, <?php echo empty($Server->Name())?'true':'false' ?>)">
+      <form name="contentForm" method="post" action="?" class="validateFormOnSubmit">
         <input type="hidden" name="view" value="<?php echo $view ?>"/>
         <input type="hidden" name="object" value="server"/>
         <input type="hidden" name="id" value="<?php echo validHtmlStr($_REQUEST['id']) ?>"/>
@@ -94,12 +94,18 @@ xhtmlHeaders(__FILE__, translate('Server').' - '.$Server->Name());
                 <input type="radio" name="newServer[zmtrigger]" value="0"<?php echo $Server->zmtrigger() ? '' : ' checked="checked"' ?>/> No
               </td>
             </tr>
+            <tr>
+              <th scope="row"><?php echo translate('RunEventNotification') ?></th>
+              <td>
+                <input type="radio" name="newServer[zmeventnotification]" value="1"<?php echo $Server->zmeventnotification() ? ' checked="checked"' : '' ?>/> Yes
+                <input type="radio" name="newServer[zmeventnotification]" value="0"<?php echo $Server->zmeventnotification() ? '' : ' checked="checked"' ?>/> No
+              </td>
+            </tr>
           </tbody>
         </table>
         <div id="contentButtons">
-          <input type="hidden" name="action" value="Save"/>
-          <input type="submit" value="<?php echo translate('Save') ?>"/>
-          <input type="button" value="<?php echo translate('Cancel') ?>" onclick="closeWindow();"/>
+          <button type="submit" name="action" value="Save" ><?php echo translate('Save') ?></button>
+          <button type="button" data-on-click="closeWindow"><?php echo translate('Cancel') ?></button>
         </div>
       </form>
     </div>
