@@ -51,24 +51,20 @@ define( 'STRF_TL_AXIS_RANGE_TIME2', STRF_TL_AXIS_RANGE_TIME1.', %d %b %Y' );
 //
 // These are the time axis tick labels
 //
-define( "STRF_TL_AXIS_LABEL_YEAR", "%Y" );
-define( "STRF_TL_AXIS_LABEL_MONTH", "%M" );
-define( "STRF_TL_AXIS_LABEL_WEEK", "%d/%m" );
-define( "STRF_TL_AXIS_LABEL_DAY", "%d" );
-define( "STRF_TL_AXIS_LABEL_4HOUR", "%H:00" );
-define( "STRF_TL_AXIS_LABEL_HOUR", "%H:00" );
-define( "STRF_TL_AXIS_LABEL_10MINUTE", "%H:%M" );
-define( "STRF_TL_AXIS_LABEL_MINUTE", "%H:%M" );
-define( "STRF_TL_AXIS_LABEL_10SECOND", "%S" );
-define( "STRF_TL_AXIS_LABEL_SECOND", "%S" );
+define( 'STRF_TL_AXIS_LABEL_YEAR', '%Y' );
+define( 'STRF_TL_AXIS_LABEL_MONTH', '%M' );
+define( 'STRF_TL_AXIS_LABEL_WEEK', '%d/%m' );
+define( 'STRF_TL_AXIS_LABEL_DAY', '%d' );
+define( 'STRF_TL_AXIS_LABEL_4HOUR', '%H:00' );
+define( 'STRF_TL_AXIS_LABEL_HOUR', '%H:00' );
+define( 'STRF_TL_AXIS_LABEL_10MINUTE', '%H:%M' );
+define( 'STRF_TL_AXIS_LABEL_MINUTE', '%H:%M' );
+define( 'STRF_TL_AXIS_LABEL_10SECOND', '%S' );
+define( 'STRF_TL_AXIS_LABEL_SECOND', '%S' );
 
-$mouseover = true;
-if ( !isset($mouseover) )
-  $mouseover = true;
+$mouseover = isset($_REQUEST['mouseover']) ? $_REQUEST['mouseover'] : true;
 
-$mode = 'overlay';
-if ( !isset($mode) )
-  $mode = 'overlay';
+$mode = isset($_REQUEST['mode']) ? $_REQUEST['mode'] : 'overlay';
 
 $minEventWidth = 3;
 $maxEventWidth = 6;
@@ -130,19 +126,11 @@ $chart = array(
 );
 
 $monitors = array();
-$monitorsSql = 'SELECT * FROM Monitors ORDER BY Sequence ASC';
-//srand( 97981 );
-foreach( dbFetchAll( $monitorsSql ) as $row ) {
-  //if ( empty($row['WebColour']) )
-  //{
-      //$row['WebColour'] = sprintf( "#%02x%02x%02x", rand( 0, 255 ), rand( 0, 255), rand( 0, 255 ) );
-  //}
-  $monitors[$row['Id']] = $row;
-}
 
 # The as E, and joining with Monitors is required for the filterSQL filters.
 $rangeSql = 'SELECT min(E.StartTime) AS MinTime, max(E.EndTime) AS MaxTime FROM Events AS E INNER JOIN Monitors AS M ON (E.MonitorId = M.Id) WHERE NOT isnull(E.StartTime) AND NOT isnull(E.EndTime)';
 $eventsSql = 'SELECT E.* FROM Events AS E INNER JOIN Monitors AS M ON (E.MonitorId = M.Id) WHERE NOT isnull(StartTime)';
+$eventIdsSql = 'SELECT E.Id FROM Events AS E INNER JOIN Monitors AS M ON (E.MonitorId = M.Id) WHERE NOT isnull(StartTime)';
 $eventsValues = array();
 
 if ( !empty($user['MonitorIds']) ) {
@@ -150,12 +138,12 @@ if ( !empty($user['MonitorIds']) ) {
 
   $rangeSql .= $monFilterSql;
   $eventsSql .= $monFilterSql;
+  $eventIdsSql .= $monFilterSql;
 }
 
+$tree = false;
 if ( isset($_REQUEST['filter']) )
   $tree = parseFilterToTree($_REQUEST['filter']['Query']);
-else
-  $tree = false;
 
 if ( isset($_REQUEST['range']) )
   $range = validHtmlStr($_REQUEST['range']);
@@ -166,7 +154,7 @@ if ( isset($_REQUEST['midTime']) )
 if ( isset($_REQUEST['maxTime']) )
   $maxTime = validHtmlStr($_REQUEST['maxTime']);
 
-if ( isset($range) ) {
+if ( isset($range) and validInt($range) ) {
   $halfRange = (int)($range/2);
   if ( isset($midTime) ) {
     $midTimeT = strtotime($midTime);
@@ -207,6 +195,7 @@ if ( isset($minTime) && isset($maxTime) ) {
   if ( $filterSql ) {
     $filterSql = " AND $filterSql";
     $eventsSql .= $filterSql;
+    $eventIdsSql .= $filterSql;
   }
 } else {
   $filterSql = parseTreeToSQL($tree);
@@ -217,16 +206,20 @@ if ( isset($minTime) && isset($maxTime) ) {
     $filterSql = " AND $filterSql";
     $rangeSql .= $filterSql;
     $eventsSql .= $filterSql;
+    $eventIdsSql .= $filterSql;
   }
 
   if ( !isset($minTime) || !isset($maxTime) ) {
     // Dynamically determine range
     $row = dbFetchOne($rangeSql);
-
-    if ( !isset($minTime) )
-      $minTime = $row['MinTime'];
-    if ( !isset($maxTime) )
-      $maxTime = $row['MaxTime'];
+    if ( $row ) {
+      if ( !isset($minTime) )
+        $minTime = $row['MinTime'];
+      if ( !isset($maxTime) )
+        $maxTime = $row['MaxTime'];
+    } else {
+      # Errors will be reported by db functions
+    }
   }
 
   if ( empty($minTime) )
@@ -256,13 +249,13 @@ if ( $tree ) {
 $scales = array(
   array( 'name'=>'year',     'factor'=>60*60*24*365, 'align'=>1,  'zoomout'=>2,    'label'=>STRF_TL_AXIS_LABEL_YEAR ),
   array( 'name'=>'month',    'factor'=>60*60*24*30,  'align'=>1,  'zoomout'=>12,   'label'=>STRF_TL_AXIS_LABEL_MONTH ),
-  array( 'name'=>'week',     'factor'=>60*60*24*7,   'align'=>1,  'zoomout'=>4.25, 'label'=>STRF_TL_AXIS_LABEL_WEEK,     'labelCheck'=>"%W" ),
+  array( 'name'=>'week',     'factor'=>60*60*24*7,   'align'=>1,  'zoomout'=>4.25, 'label'=>STRF_TL_AXIS_LABEL_WEEK,     'labelCheck'=>'%W' ),
   array( 'name'=>'day',      'factor'=>60*60*24,     'align'=>1,  'zoomout'=>7,    'label'=>STRF_TL_AXIS_LABEL_DAY ),
-  array( 'name'=>"hour4",    'factor'=>60*60,        'align'=>4,  'zoomout'=>6,    'label'=>STRF_TL_AXIS_LABEL_4HOUR,    'labelCheck'=>"%H" ),
-  array( 'name'=>'hour',     'factor'=>60*60,        'align'=>1,  'zoomout'=>4,    'label'=>STRF_TL_AXIS_LABEL_HOUR,     'labelCheck'=>"%H" ),
-  array( 'name'=>"minute10", 'factor'=>60,           'align'=>10, 'zoomout'=>6,    'label'=>STRF_TL_AXIS_LABEL_10MINUTE, 'labelCheck'=>"%M" ),
-  array( 'name'=>'minute',   'factor'=>60,           'align'=>1,  'zoomout'=>10,   'label'=>STRF_TL_AXIS_LABEL_MINUTE,   'labelCheck'=>"%M" ),
-  array( 'name'=>"second10", 'factor'=>1,            'align'=>10, 'zoomout'=>6,    'label'=>STRF_TL_AXIS_LABEL_10SECOND ),
+  array( 'name'=>'hour4',    'factor'=>60*60,        'align'=>4,  'zoomout'=>6,    'label'=>STRF_TL_AXIS_LABEL_4HOUR,    'labelCheck'=>'%H' ),
+  array( 'name'=>'hour',     'factor'=>60*60,        'align'=>1,  'zoomout'=>4,    'label'=>STRF_TL_AXIS_LABEL_HOUR,     'labelCheck'=>'%H' ),
+  array( 'name'=>'minute10', 'factor'=>60,           'align'=>10, 'zoomout'=>6,    'label'=>STRF_TL_AXIS_LABEL_10MINUTE, 'labelCheck'=>'%M' ),
+  array( 'name'=>'minute',   'factor'=>60,           'align'=>1,  'zoomout'=>10,   'label'=>STRF_TL_AXIS_LABEL_MINUTE,   'labelCheck'=>'%M' ),
+  array( 'name'=>'second10', 'factor'=>1,            'align'=>10, 'zoomout'=>6,    'label'=>STRF_TL_AXIS_LABEL_10SECOND ),
   array( 'name'=>'second',   'factor'=>1,            'align'=>1,  'zoomout'=>10,   'label'=>STRF_TL_AXIS_LABEL_SECOND ),
 );
 
@@ -280,20 +273,24 @@ $halfRange = (int)($range/2);
 $midTimeT = $minTimeT + $halfRange;
 $midTime = strftime(STRF_FMT_DATETIME_DB, $midTimeT);
 
-//echo "R:$range<br>";
-//echo "MnT:$minTime<br>";
-//echo "MnTt:$minTimeT<br>";
-//echo "MdT:$midTime<br>";
-//echo "MdTt:$midTimeT<br>";
-//echo "MxT:$maxTime<br>";
-//echo "MxTt:$maxTimeT<br>";
-
 if ( isset($minTime) && isset($maxTime) ) {
   $eventsSql .= " AND EndTime >= '$minTime' AND StartTime <= '$maxTime'";
+  $eventIdsSql .= " AND EndTime >= '$minTime' AND StartTime <= '$maxTime'";
 }
 
+if ( 0 ) {
+$framesByEventId = array();
 $eventsSql .= ' ORDER BY E.Id ASC';
-//echo "ESQL: $eventsSql<br>";
+$framesSql = "SELECT EventId,FrameId,Delta,Score FROM Frames WHERE EventId IN($eventIdsSql) AND Score > 0 ORDER BY Score DESC";
+$frames_result = dbQuery($framesSql);
+while ( $row = $frames_result->fetch(PDO::FETCH_ASSOC) ) {
+  if ( !isset($framesByEventId[$row['EventId']]) ) {
+    $framesByEventId[$row['EventId']] = array();
+  }
+  $framesByEventId[$row['EventId']][] = $row;
+}
+}
+
 
 $chart['data'] = array(
   'x' => array(
@@ -311,107 +308,106 @@ $chart['data']['x']['density'] = $chart['data']['x']['range']/$chart['graph']['w
 
 $monEventSlots = array();
 $monFrameSlots = array();
-$monitorIds = array();
-$events_result = dbQuery( $eventsSql );
-if ( ! $events_result ) {
-  Fatal( "SQL-ERR");
+$events_result = dbQuery($eventsSql);
+if ( !$events_result ) {
+  ZM\Fatal('SQL-ERR');
   return;
 }
 
-$first_event = $event = $events_result->fetch(PDO::FETCH_ASSOC);
-if ( $event ) {
-  do {
-    if ( !isset($monitorIds[$event['MonitorId']]) ) {
-      $monitorIds[$event['MonitorId']] = true;
-      $monEventSlots[$event['MonitorId']] = array();
-      $monFrameSlots[$event['MonitorId']] = array();
-    }
+$max_aspect_ratio = 0;
 
-    $currEventSlots = &$monEventSlots[$event['MonitorId']];
-    $currFrameSlots = &$monFrameSlots[$event['MonitorId']];
+while( $event = $events_result->fetch(PDO::FETCH_ASSOC) ) {
+  if ( !isset($monitors[$event['MonitorId']]) ) {
+    $monitor = $monitors[$event['MonitorId']] = ZM\Monitor::find_one(array('Id'=>$event['MonitorId']));
+    $monEventSlots[$event['MonitorId']] = array();
+    $monFrameSlots[$event['MonitorId']] = array();
+    $aspect_ratio = round($monitor->Width() / $monitor->Height(), 2);
+    if ( $aspect_ratio > $max_aspect_ratio )
+      $max_aspect_ratio = $aspect_ratio;
+  }
 
-    $startTimeT = strtotime($event['StartTime']);
-    $startIndex = $rawStartIndex = (int)(($startTimeT - $chart['data']['x']['lo']) / $chart['data']['x']['density']);
-    if ( $startIndex < 0 )
-      $startIndex = 0;
+  $currEventSlots = &$monEventSlots[$event['MonitorId']];
+  $currFrameSlots = &$monFrameSlots[$event['MonitorId']];
 
-    if ( isset($event['EndTime']) )
-      $endTimeT = strtotime($event['EndTime']);
-    else
-      $endTimeT = time();
-    $endIndex = $rawEndIndex = (int)(($endTimeT - $chart['data']['x']['lo']) / $chart['data']['x']['density']);
+  $startTimeT = strtotime($event['StartTime']);
+  $startIndex = $rawStartIndex = (int)(($startTimeT - $chart['data']['x']['lo']) / $chart['data']['x']['density']);
+  if ( $startIndex < 0 )
+    $startIndex = 0;
 
-    if ( $endIndex >= $chart['graph']['width'] )
-      $endIndex = $chart['graph']['width'] - 1;
+  if ( isset($event['EndTime']) )
+    $endTimeT = strtotime($event['EndTime']);
+  else
+    $endTimeT = time();
+  $endIndex = $rawEndIndex = (int)(($endTimeT - $chart['data']['x']['lo']) / $chart['data']['x']['density']);
 
-    for ( $i = $startIndex; $i <= $endIndex; $i++ ) {
-      if ( !isset($currEventSlots[$i]) ) {
-        if ( $rawStartIndex == $rawEndIndex ) {
-          $offset = 1;
-        } else {
-          $offset = 1 + ($event['Frames']?((int)(($event['Frames']-1)*(($i-$rawStartIndex)/($rawEndIndex-$rawStartIndex)))):0);
-        }
-        $currEventSlots[$i] = array( 'count'=>0, 'width'=>1, 'offset'=>$offset, 'event'=>$event );
+  if ( $endIndex >= $chart['graph']['width'] )
+    $endIndex = $chart['graph']['width'] - 1;
+
+  for ( $i = $startIndex; $i <= $endIndex; $i++ ) {
+    if ( !isset($currEventSlots[$i]) ) {
+      if ( $rawStartIndex == $rawEndIndex ) {
+        $offset = 1;
       } else {
-        $currEventSlots[$i]['count']++;
+        $offset = 1 + ($event['Frames']?((int)(($event['Frames']-1)*(($i-$rawStartIndex)/($rawEndIndex-$rawStartIndex)))):0);
       }
+      $currEventSlots[$i] = array( 'count'=>0, 'width'=>1, 'offset'=>$offset, 'event'=>$event );
+    } else {
+      $currEventSlots[$i]['count']++;
     }
+  }
 
-    if ( $event['MaxScore'] > 0 ) {
-      if ( $startIndex == $endIndex ) {
-        # Only fills 1 slot, so just get the max Score
-        $framesSql = 'SELECT FrameId,Score FROM Frames WHERE EventId = ? AND Score > 0 ORDER BY Score DESC LIMIT 1';
-        $frame = dbFetchOne($framesSql, NULL, array($event['Id']));
+  if ( $event['MaxScore'] > 0 ) {
+    if ( $startIndex == $endIndex ) {
+      # Only fills 1 slot, so just get the max Score
+      $framesSql = 'SELECT FrameId, Score FROM Frames WHERE EventId = ? AND Score > 0 ORDER BY Score DESC LIMIT 1';
+      $frame = dbFetchOne($framesSql, NULL, array($event['Id']));
 
-        $i = $startIndex;
-        if ( !isset($currFrameSlots[$i]) ) {
-          $currFrameSlots[$i] = array('count'=>1, 'value'=>$event['MaxScore'], 'event'=>$event, 'frame'=>$frame);
-        } else {
-          $currFrameSlots[$i]['count']++;
-          if ( $event['MaxScore'] > $currFrameSlots[$i]['value'] ) {
-            $currFrameSlots[$i]['value'] = $event['MaxScore'];
-            $currFrameSlots[$i]['event'] = $event;
-            $currFrameSlots[$i]['frame'] = $frame;
-          }
-        }
-        if ( $event['MaxScore'] > $chart['data']['y']['hi'] ) {
-          $chart['data']['y']['hi'] = $event['MaxScore'];
-        }
+      $i = $startIndex;
+      if ( !isset($currFrameSlots[$i]) ) {
+        $currFrameSlots[$i] = array('count'=>1, 'value'=>$event['MaxScore'], 'event'=>$event, 'frame'=>$frame);
       } else {
-        # Fills multiple Slots, so need multiple scores to generate the graph over multiple slots.
-        $framesSql = 'SELECT FrameId,Delta,unix_timestamp(TimeStamp) AS TimeT,Score FROM Frames WHERE EventId = ? AND Score > 0';
-        $result = dbQuery($framesSql, array($event['Id']));
-        while( $frame = dbFetchNext($result) ) {
-          if ( $frame['Score'] == 0 )
-            continue;
-          $frameTimeT = $frame['TimeT'];
-          $frameTimeT = $startTimeT + $frame['Delta'];
-          $frameIndex = (int)(($frameTimeT - $chart['data']['x']['lo']) / $chart['data']['x']['density']);
-          if ( $frameIndex < 0 )
-            continue;
-          if ( $frameIndex >= $chart['graph']['width'] )
-            continue;
-
-          if ( !isset($currFrameSlots[$frameIndex]) ) {
-            $currFrameSlots[$frameIndex] = array('count'=>1, 'value'=>$frame['Score'], 'event'=>$event, 'frame'=>$frame);
-          } else {
-            $currFrameSlots[$frameIndex]['count']++;
-            if ( $frame['Score'] > $currFrameSlots[$frameIndex]['value'] ) {
-              $currFrameSlots[$frameIndex]['value'] = $frame['Score'];
-              $currFrameSlots[$frameIndex]['event'] = $event;
-              $currFrameSlots[$frameIndex]['frame'] = $frame;
-            }
-          }
-          if ( $frame['Score'] > $chart['data']['y']['hi'] ) {
-            $chart['data']['y']['hi'] = $frame['Score'];
-          }
-        } // end foreach frame
+        $currFrameSlots[$i]['count']++;
+        if ( $event['MaxScore'] > $currFrameSlots[$i]['value'] ) {
+          $currFrameSlots[$i]['value'] = $event['MaxScore'];
+          $currFrameSlots[$i]['event'] = $event;
+          $currFrameSlots[$i]['frame'] = $frame;
+        }
       }
-    } // end if MaxScore > 0
-  } while( $event = $events_result->fetch( PDO::FETCH_ASSOC ) );
-} # end if have first event
+      if ( $event['MaxScore'] > $chart['data']['y']['hi'] ) {
+        $chart['data']['y']['hi'] = $event['MaxScore'];
+      }
+    } else {
+      # Fills multiple Slots, so need multiple scores to generate the graph over multiple slots.
+      $framesSql = 'SELECT FrameId,Delta,Score FROM Frames WHERE EventId = ? AND Score > 0';
+      $result = dbQuery($framesSql, array($event['Id']));
+      while ( $frame = dbFetchNext($result) ) {
+      #foreach ( $framesByEventId[$event['Id']] as $frame ) {
+        $frameTimeT = $startTimeT + $frame['Delta'];
+        $frameIndex = (int)(($frameTimeT - $chart['data']['x']['lo']) / $chart['data']['x']['density']);
+        if ( $frameIndex < 0 )
+          continue;
+        if ( $frameIndex >= $chart['graph']['width'] )
+          continue;
 
-ksort( $monitorIds, SORT_NUMERIC );
+        if ( !isset($currFrameSlots[$frameIndex]) ) {
+          $currFrameSlots[$frameIndex] = array('count'=>1, 'value'=>$frame['Score'], 'event'=>$event, 'frame'=>$frame);
+        } else {
+          $currFrameSlots[$frameIndex]['count']++;
+          if ( $frame['Score'] > $currFrameSlots[$frameIndex]['value'] ) {
+            $currFrameSlots[$frameIndex]['value'] = $frame['Score'];
+            $currFrameSlots[$frameIndex]['event'] = $event;
+            $currFrameSlots[$frameIndex]['frame'] = $frame;
+          }
+        }
+        if ( $frame['Score'] > $chart['data']['y']['hi'] ) {
+          $chart['data']['y']['hi'] = $frame['Score'];
+        }
+      } // end foreach frame
+    }
+  } // end if MaxScore > 0
+} // end foreach event
+
+//ksort( $monitorIds, SORT_NUMERIC );
 ksort( $monEventSlots, SORT_NUMERIC );
 ksort( $monFrameSlots, SORT_NUMERIC );
 
@@ -424,7 +420,7 @@ if ( false ) {
     for ( $i = 0; $i < $chart['graph']['width']; $i++ ) {
       if ( isset($currFrameSlots[$i]) ) {
         if ( !isset($currFrameSlots[$i]['frame']) ) {
-          $framesSql = "SELECT FrameId,Score FROM Frames WHERE EventId = ? AND Score > 0 ORDER BY FrameId LIMIT 1";
+          $framesSql = 'SELECT FrameId, Score FROM Frames WHERE EventId = ? AND Score > 0 ORDER BY FrameId LIMIT 1';
           $currFrameSlots[$i]['frame'] = dbFetchOne( $framesSql, NULL, array( $currFrameSlots[$i]['event']['Id'] ) );
         }
       }
@@ -440,16 +436,6 @@ $majYScale = getYScale(
   $chart['grid']['y']['major']['min'],
   $chart['grid']['y']['major']['max']);
 
-$maxWidth = 0;
-$maxHeight = 0;
-
-foreach ( array_keys($monitorIds) as $monitorId ) {
-  if ( $maxWidth < $monitors[$monitorId]['Width'] )
-    $maxWidth = $monitors[$monitorId]['Width'];
-  if ( $maxHeight < $monitors[$monitorId]['Height'] )
-    $maxHeight = $monitors[$monitorId]['Height'];
-}
-
 // Optimise boxes
 foreach( array_keys($monEventSlots) as $monitorId ) {
   unset( $currEventSlots );
@@ -463,11 +449,11 @@ foreach( array_keys($monEventSlots) as $monitorId ) {
             $currSlot['width']++;
             unset( $currEventSlots[$i] );
             continue;
-          } elseif ( $currSlot['offset'] < $currEventSlots[$i]['offset'] ) {
+          } else if ( $currSlot['offset'] < $currEventSlots[$i]['offset'] ) {
             // Split very long events
             $currEventSlots[$i]['frame'] = array( 'FrameId'=>$currEventSlots[$i]['offset'] );
           }
-        } elseif ( $currSlot['width'] < $minEventWidth ) {
+        } else if ( $currSlot['width'] < $minEventWidth ) {
           // Merge multiple small events
           $currSlot['width']++;
           unset( $currEventSlots[$i] );
@@ -476,11 +462,10 @@ foreach( array_keys($monEventSlots) as $monitorId ) {
       }
       $currSlot = &$currEventSlots[$i];
     } else {
-      unset( $currSlot );
+      unset($currSlot);
     }
-  }
-  if ( isset($currSlot) )
-    unset($currSlot);
+  }  # end foreach x
+  unset($currSlot);
 } // end foreach Event Monitors
 //print_r( $monEventSlots );
 
@@ -489,7 +474,6 @@ $frameSlots = array();
 $frameMonitorIds = array_keys($monFrameSlots);
 for ( $i = 0; $i < $chart['graph']['width']; $i++ ) {
   foreach ( $frameMonitorIds as $frameMonitorId ) {
-    unset($currFrameSlots);
     $currFrameSlots = &$monFrameSlots[$frameMonitorId];
     if ( isset($currFrameSlots[$i]) ) {
       if ( !isset($frameSlots[$i]) ) {
@@ -509,10 +493,11 @@ for ( $i = 0; $i < $chart['graph']['width']; $i++ ) {
         $frameSlots[$i][] = &$currFrameSlots[$i];
       }
     }
+    unset($currFrameSlots);
   } # end foreach MonitorId
-}
+}  # end foreach x
 
-//print_r( $monEventSlots );
+ZM\Logger::Debug(print_r( $monEventSlots,true ));
 //print_r( $monFrameSlots );
 //print_r( $chart );
 
@@ -522,9 +507,9 @@ if ( $mode == 'overlay' ) {
   $minEventBarHeight = 10;
   $maxEventBarHeight = 40;
 
-  if ( count($monitorIds) ) {
+  if ( count($monitors) ) {
     $chart['graph']['eventBarHeight'] = $minEventBarHeight;
-    while ( ($chart['graph']['eventsHeight'] = (($chart['graph']['eventBarHeight'] * count($monitorIds)) + (count($monitorIds)-1))) < $maxEventBarHeight ) {
+    while ( ($chart['graph']['eventsHeight'] = (($chart['graph']['eventBarHeight'] * count($monitors)) + (count($monitors)-1))) < $maxEventBarHeight ) {
       $chart['graph']['eventBarHeight']++;
     }
   } else {
@@ -536,7 +521,7 @@ if ( $mode == 'overlay' ) {
 
   $chart['eventBars'] = array();
   $top = $chart['graph']['activityHeight'];
-  foreach ( array_keys($monitorIds) as $monitorId ) {
+  foreach ( array_keys($monitors) as $monitorId ) {
     $chart['eventBars'][$monitorId] = array( 'top' => $top );
     $top += $chart['graph']['eventBarHeight']+1;
   }
@@ -545,10 +530,10 @@ if ( $mode == 'overlay' ) {
   $minEventBarHeight = 10;
   $maxEventBarHeight = 40;
 
-  if ( count($monitorIds) ) {
+  if ( count($monitors) ) {
     $chart['graph']['eventBarHeight'] = $minEventBarHeight;
     $chart['graph']['activityBarHeight'] = $minActivityBarHeight;
-    while ( ((($chart['graph']['eventBarHeight']+$chart['graph']['activityBarHeight']) * count($monitorIds)) + ((2*count($monitorIds))-1)) < $graphHeight ) {
+    while ( ((($chart['graph']['eventBarHeight']+$chart['graph']['activityBarHeight']) * count($monitors)) + ((2*count($monitors))-1)) < $graphHeight ) {
       $chart['graph']['activityBarHeight']++;
       if ( $chart['graph']['eventBarHeight'] < $maxEventBarHeight ) {
         $chart['graph']['eventBarHeight']++;
@@ -564,28 +549,30 @@ if ( $mode == 'overlay' ) {
   $chart['eventBars'] = array();
   $top = 0;
   $barCount = 1;
-  foreach ( array_keys($monitorIds) as $monitorId ) {
+  foreach ( array_keys($monitors) as $monitorId ) {
     $chart['eventBars'][$monitorId] = array( 'top' => $top );
     $chart['eventBars'][$monitorId] = array( 'top' => $top+$chart['graph']['activityBarHeight']+1 );
     $top +=  $chart['graph']['activityBarHeight']+1+$chart['graph']['eventBarHeight']+1;
   }
+} else {
+  ZM\Warning("No mode $mode");
 }
 
-preg_match( '/^(\d+)-(\d+)-(\d+) (\d+):(\d+)/', $minTime, $startMatches );
-preg_match( '/^(\d+)-(\d+)-(\d+) (\d+):(\d+)/', $maxTime, $endMatches );
+preg_match('/^(\d+)-(\d+)-(\d+) (\d+):(\d+)/', $minTime, $startMatches);
+preg_match('/^(\d+)-(\d+)-(\d+) (\d+):(\d+)/', $maxTime, $endMatches);
 
 if ( $startMatches[1] != $endMatches[1] ) {
   // Different years
-  $title = strftime( STRF_TL_AXIS_RANGE_YEAR1, $chart['data']['x']['lo'] )." - ".strftime( STRF_TL_AXIS_RANGE_YEAR2, $chart['data']['x']['hi'] );
-} elseif ( $startMatches[2] != $endMatches[2] ) {
+  $title = strftime( STRF_TL_AXIS_RANGE_YEAR1, $chart['data']['x']['lo'] ).' - '.strftime( STRF_TL_AXIS_RANGE_YEAR2, $chart['data']['x']['hi'] );
+} else if ( $startMatches[2] != $endMatches[2] ) {
   // Different months
-  $title = strftime( STRF_TL_AXIS_RANGE_MONTH1, $chart['data']['x']['lo'] )." - ".strftime( STRF_TL_AXIS_RANGE_MONTH2, $chart['data']['x']['hi'] );
-} elseif ( $startMatches[3] != $endMatches[3] ) {
+  $title = strftime( STRF_TL_AXIS_RANGE_MONTH1, $chart['data']['x']['lo'] ).' - '.strftime( STRF_TL_AXIS_RANGE_MONTH2, $chart['data']['x']['hi'] );
+} else if ( $startMatches[3] != $endMatches[3] ) {
   // Different dates
-  $title = strftime( STRF_TL_AXIS_RANGE_DAY1, $chart['data']['x']['lo'] )." - ".strftime( STRF_TL_AXIS_RANGE_DAY2, $chart['data']['x']['hi'] );
+  $title = strftime( STRF_TL_AXIS_RANGE_DAY1, $chart['data']['x']['lo'] ).' - '.strftime( STRF_TL_AXIS_RANGE_DAY2, $chart['data']['x']['hi'] );
 } else {
   // Different times
-  $title = strftime( STRF_TL_AXIS_RANGE_TIME1, $chart['data']['x']['lo'] )." - ".strftime( STRF_TL_AXIS_RANGE_TIME2, $chart['data']['x']['hi'] );
+  $title = strftime( STRF_TL_AXIS_RANGE_TIME1, $chart['data']['x']['lo'] ).' - '.strftime( STRF_TL_AXIS_RANGE_TIME2, $chart['data']['x']['hi'] );
 }
 
 function drawXGrid( $chart, $scale, $labelClass, $tickClass, $gridClass, $zoomClass=false ) {
@@ -595,11 +582,9 @@ function drawXGrid( $chart, $scale, $labelClass, $tickClass, $gridClass, $zoomCl
   $lastTick = 0;
   unset( $lastLabel );
   $labelCheck = isset($scale['labelCheck'])?$scale['labelCheck']:$scale['label'];
-?>
-          <div id='xScale'>
-<?php
+  echo '<div id="xScale">';
   for ( $i = 0; $i < $chart['graph']['width']; $i++ ) {
-    $x = $i - 1;
+    $x = round(100*(($i)/$chart['graph']['width']),1);
     $timeOffset = (int)($chart['data']['x']['lo'] + ($i * $chart['data']['x']['density']));
     if ( $scale['align'] > 1 ) {
       $label = (int)(strftime( $labelCheck, $timeOffset )/$scale['align']);
@@ -614,24 +599,24 @@ function drawXGrid( $chart, $scale, $labelClass, $tickClass, $gridClass, $zoomCl
       if ( isset($lastLabel) ) {
         if ( $labelClass ) {
 ?>
-            <div class="<?php echo $labelClass ?>" style="left: <?php echo $x-25 ?>px;"><?php echo strftime( $scale['label'], $timeOffset ); ?></div>
+            <div class="<?php echo $labelClass ?>" style="left: <?php echo $x-round(100*(11/$chart['graph']['width']),1) ?>%;"><?php echo strftime( $scale['label'], $timeOffset ); ?></div>
 <?php
         }
         if ( $tickClass ) {
 ?>
-            <div class="<?php echo $tickClass ?>" style="left: <?php echo $x ?>px;"></div>
+            <div class="<?php echo $tickClass ?>" style="left: <?php echo $x ?>%;"></div>
 <?php
         }
         if ( $gridClass ) {
 ?>
-            <div class="<?php echo $gridClass ?>" style="left: <?php echo $x ?>px;"></div>
+            <div class="<?php echo $gridClass ?>" style="left: <?php echo $x ?>%;"></div>
 <?php
         }
         if ( $scale['name'] != 'second' && $zoomClass ) {
           $zoomMinTime = strftime( STRF_FMT_DATETIME_DB, (int)($chart['data']['x']['lo'] + ($lastTick * $chart['data']['x']['density'])) );
           $zoomMaxTime = strftime( STRF_FMT_DATETIME_DB, (int)($chart['data']['x']['lo'] + ($i * $chart['data']['x']['density'])) );
 ?>
-            <div class="<?php echo $zoomClass ?>" style="left: <?php echo $lastTick-1 ?>px; width: <?php echo $i-$lastTick ?>px;" title="<?php echo translate('ZoomIn') ?>" onclick="tlZoomBounds( '<?php echo $zoomMinTime ?>', '<?php echo $zoomMaxTime ?>' )"></div>
+            <div class="<?php echo $zoomClass ?>" style="left: <?php echo 100*($lastTick-1)/$chart['graph']['width'] ?>%; width: <?php echo round(100*($i-$lastTick)/$chart['graph']['width'],1) ?>%;" title="<?php echo translate('ZoomIn') ?>" data-on-click="tlZoomBounds" data-zoom-min-time="<?php echo $zoomMinTime ?>" data-zoom-max-time="<?php echo $zoomMaxTime ?>"></div>
 <?php
         }
         $lastTick = $i;
@@ -644,19 +629,19 @@ function drawXGrid( $chart, $scale, $labelClass, $tickClass, $gridClass, $zoomCl
     $zoomMinTime = strftime( STRF_FMT_DATETIME_DB, (int)($chart['data']['x']['lo'] + ($lastTick * $chart['data']['x']['density'])) );
     $zoomMaxTime = strftime( STRF_FMT_DATETIME_DB, (int)($chart['data']['x']['lo'] + ($i * $chart['data']['x']['density'])) );
 ?>
-            <div class="<?php echo $zoomClass ?>" style="left: <?php echo $lastTick-1 ?>px; width: <?php echo $i-$lastTick ?>px;" title="<?php echo translate('ZoomIn') ?>" onclick="tlZoomBounds( '<?php echo $zoomMinTime ?>', '<?php echo $zoomMaxTime ?>' )"></div>
+            <div class="<?php echo $zoomClass ?>" style="left: <?php echo $lastTick-1 ?>px; width: <?php echo $i-$lastTick ?>px;" title="<?php echo translate('ZoomIn') ?>" data-on-click="tlZoomBounds" data-zoom-min-time="<?php echo $zoomMinTime ?>" data-zoom-max-time="<?php echo $zoomMaxTime ?>"></div>
 <?php
   }
 ?>
           </div>
 <?php
-  return( ob_get_clean() );
+  return ob_get_clean();
 } # end function drawXGrid
 
 function drawYGrid( $chart, $scale, $labelClass, $tickClass, $gridClass ) {
   ob_start();
 ?>
-  <div id='yScale'>
+  <div id="yScale">
 <?php
   for ( $i = 0; $i < $scale['lines']; $i++ ) {
     $label = (int)($i * $scale['divisor']);
@@ -680,171 +665,130 @@ function drawYGrid( $chart, $scale, $labelClass, $tickClass, $gridClass ) {
 ?>
   </div>
 <?php
-  return( ob_get_clean() );
+  return ob_get_clean();
 } # end function drawYGrid
 
-function getSlotPreviewEventBehaviour( $slot ) {
-  return( "previewEvent( '".$slot['event']['Id']."', '".getSlotFrame( $slot )."' )" );
-}
-
-function getSlotShowEventBehaviour( $slot ) {
-  global $monitors;
-
-  $monitor = &$monitors[$slot['event']['MonitorId']];
-
-  return( "showEvent( '".$slot['event']['Id']."', '".getSlotFrame( $slot )."', '".reScale( $monitor['Width'], $monitor['DefaultScale'], ZM_WEB_DEFAULT_SCALE )."', '".reScale( $monitor['Height'], $monitor['DefaultScale'], ZM_WEB_DEFAULT_SCALE )."' )" );
-}
-
 $focusWindow = true;
 
-xhtmlHeaders(__FILE__, translate('Timeline') );
+xhtmlHeaders(__FILE__, translate('Timeline'));
 ?>
 <body>
-  <div id='page'>
+  <div id="page">
   <?php echo getNavBarHTML() ?>
-    <div id='header'>
-      <div id='info'>
+    <div id="header">
+      <div id="info">
         <h2><?php echo translate('Timeline') ?></h2>
-        <a id='refreshLink' href="#" onclick="location.reload(true);"><?php echo translate('Refresh') ?></a>
+        <a id="refreshLink" href="#" data-on-click="refreshWindow"><?php echo translate('Refresh') ?></a>
       </div>
-      <div id='headerButtons'>
-        <a href="#" onclick="window.history.back();"><?php echo translate('Back') ?></a>
+      <div id="headerButtons">
+        <a href="#" data-on-click="backWindow"><?php echo translate('Back') ?></a>
         <a href="?view=events&amp;page=1<?php echo htmlspecialchars($filterQuery) ?>"><?php echo translate('List') ?></a>
       </div>
     </div>
-    <div id='content' class='chartSize'>
-      <div id='topPanel' class='graphWidth'>
-        <div id='imagePanel'>
-          <div id='image' class='imageHeight'>
-		        <img id='imageSrc' class='imageWidth' src="graphics/transparent.png" alt="<?php echo translate('ViewEvent') ?>" title="<?php echo translate('ViewEvent') ?>"/>
-<?php
-if ( 0 ) {
-//due to chrome bug, has to enable https://code.google.com/p/chromium/issues/detail?id=472300
-//crossorigin has to be added below to make caption work in chrome
-?>
-<!--
-			<video id='preview' width="100%" controls crossorigin='anonymous'>
-				<source src="<?php echo getEventDefaultVideoPath($first_event); ?>" type="video/mp4">
-Your browser does not support the video tag.
-			</video>
-o-->
-<?php } ?>
-
+    <div id="content" class="chartSize">
+      <div id="topPanel" class="graphWidth">
+        <div id="imagePanel">
+          <div id="image" class="imageHeight">
+		        <img id="imageSrc" class="imageWidth" src="graphics/transparent.png" alt="<?php echo translate('ViewEvent') ?>" title="<?php echo translate('ViewEvent') ?>"/>
           </div>
         </div>
-        <div id='dataPanel'>
-          <div id='textPanel'>
-            <div id='instruction'>
+        <div id="dataPanel">
+          <div id="textPanel">
+            <div id="instruction">
               <p><?php echo translate('TimelineTip1') ?></p>
               <p><?php echo translate('TimelineTip2') ?></p>
               <p><?php echo translate('TimelineTip3') ?></p>
               <p><?php echo translate('TimelineTip4') ?></p>
               </div>
-            <div id='eventData'>
+            <div id="eventData">
             </div>
           </div>
-          <div id='navPanel'>
-            <input type='button' title="<?php echo translate('PanLeft') ?>" value="&lt;&lt;" onclick="tlPan( '<?php echo $minTime ?>', '<?php echo $range ?>' )"/>
-            <input type='button' title="<?php echo translate('ZoomOut') ?>" value="&ndash;" onclick="tlZoomRange( '<?php echo $midTime ?>', '<?php echo (int)($range*$majXScale['zoomout']) ?>' )"/>
-            <input type='button' title="<?php echo translate('PanRight') ?>" value="&gt;&gt;" onclick="tlPan( '<?php echo $maxTime ?>', '<?php echo $range ?>' )"/>
+          <div id="navPanel">
+            <button type="button" title="<?php echo translate('PanLeft') ?>" data-on-click="tlPanLeft">
+            <i class="material-icons md-18">fast_rewind</i>
+            </button>
+            <button type="button" title="<?php echo translate('ZoomOut') ?>" data-on-click="tlZoomOut">
+<i class="material-icons md-18">zoom_out</i>
+            </button>
+            <button type="button" title="<?php echo translate('PanRight') ?>" data-on-click="tlPanRight">
+            <i class="material-icons md-18">fast_forward</i>
+            </button>
           </div>
         </div>
       </div>
-      <div id='chartPanel'>
-        <div id='chart' class='graphSize'>
+      <div id="chartPanel">
+        <div id="chart" class="graphSize">
 <?php
+
+function drawSlot($slot,$index) {
+  global $chart;
+  global $monitors;
+  global $mouseover;
+  $height = (int)($slot['value']/$chart['data']['y']['density']);
+
+  if ( $height <= 0 )
+    return '';
+  $left = round(100*($index/$chart['graph']['width']),1);
+
+  return "<div class=\"activity monitorColour{$slot['event']['MonitorId']}\"
+            style=\"left:{$left}%; height: {$height}px;\"
+  data-event-id=\"{$slot['event']['Id']}\" data-frame-id=\"".getSlotFrame($slot)."\"".
+  ( $mouseover ? ' data-on-mouseover-this="previewEvent" data-on-click-this="showEvent"' : ' data-on-click-this="previewEvent"').
+  '></div>';
+}
+
 if ( $mode == 'overlay' ) {
   echo drawYGrid( $chart, $majYScale, 'majLabelY', 'majTickY', 'majGridY graphWidth' );
 }
 echo drawXGrid( $chart, $majXScale, 'majLabelX', 'majTickX', 'majGridX graphHeight', 'zoom graphHeight' );
-Warning("Mode: $mode");
 if ( $mode == 'overlay' ) {
 ?>
-          <div id='activity' class='activitySize'>
+          <div id="activity" class="activitySize">
 <?php
     foreach ( $frameSlots as $index=>$slots ) {
       foreach ( $slots as $slot ) {
-        $slotHeight = (int)($slot['value']/$chart['data']['y']['density']);
-
-        if ( $slotHeight <= 0 )
-          continue;
-
-        if ( $mouseover ) {
-          $behaviours = array(
-              'onclick="'.getSlotShowEventBehaviour($slot).'"',
-              'onmouseover="'.getSlotPreviewEventBehaviour($slot).'"'
-              );
-        } else {
-          $behaviours = array(
-              'onclick="'.getSlotPreviewEventBehaviour($slot).'"'
-              );
-        }
-?>
-            <div class="activity monitorColour<?php echo $slot['event']['MonitorId'] ?>" style="left: <?php echo $index ?>px; height: <?php echo $slotHeight ?>px;" <?php echo join( ' ', $behaviours ) ?>></div>
-<?php
+        echo drawSlot($slot, $index);
       }
     }
 ?>
           </div>
 <?php
-} elseif ( $mode == 'split' ) {
-  foreach( array_keys($monFrameSlots) as $monitorId ) {
+} else if ( $mode == 'split' ) {
+  foreach ( array_keys($monFrameSlots) as $monitorId ) {
 ?>
-        <div id="activity<?php echo $monitorId ?>">
+        <div id="activity<?php echo $monitorId ?>" class="activitySize">
 <?php
-    unset($currFrameSlots);
     $currFrameSlots = &$monFrameSlots[$monitorId];
     foreach ( $currFrameSlots as $index=>$slot ) {
-      $slotHeight = (int)($slot['value']/$chart['data']['y']['density']);
-
-      if ( $slotHeight <= 0 )
-        continue;
-
-      if ( $mouseover ) {
-        $behaviours = array(
-          'onclick="'.getSlotShowEventBehaviour($slot).'"',
-          'onmouseover="'.getSlotPreviewEventBehaviour($slot).'"'
-        );
-      } else {
-        $behaviours = array(
-          'onclick="'.getSlotPreviewEventBehaviour($slot).'"'
-        );
-      }
-?>
-        <div class="activity activity<?php echo $slot['event']['MonitorId'] ?>" style="left: <?php echo $index ?>px; height: <?php echo $slotHeight ?>px;" <?php echo join( ' ', $behaviours ) ?>></div>
-<?php
+      echo drawSlot($slot, $index);
     } # end foreach $currFrameSlots
+    unset($currFrameSlots);
 ?>
         </div>
 <?php
   } # end foreach $MonitorId
 }
-foreach( array_keys($monEventSlots) as $monitorId ) {
+foreach ( array_keys($monEventSlots) as $monitorId ) {
 ?>
           <div id="events<?php echo $monitorId ?>" class="events eventsSize eventsPos<?php echo $monitorId ?>">
 <?php
-  unset( $currEventSlots );
   $currEventSlots = &$monEventSlots[$monitorId];
   for ( $i = 0; $i < $chart['graph']['width']; $i++ ) {
     if ( isset($currEventSlots[$i]) ) {
-      unset( $slot );
       $slot = &$currEventSlots[$i];
 
-      if ( $mouseover ) {
-        $behaviours = array(
-            'onclick="'.getSlotShowEventBehaviour($slot).'"',
-            'onmouseover="'.getSlotPreviewEventBehaviour($slot).'"'
-        );
-      } else {
-        $behaviours = array(
-            'onclick="'.getSlotPreviewEventBehaviour($slot).'"'
-        );
-      }
-?>
-            <div class="event eventsHeight monitorColour<?php echo $monitorId ?>" style="left: <?php echo $i ?>px; width: <?php echo $slot['width'] ?>px;" <?php echo join( ' ', $behaviours ) ?>></div>
-<?php
+  $left = round(100*($i/$chart['graph']['width']),1);
+  $width = round(100*($slot['width']/$chart['graph']['width']),1);
+
+  echo "<div class=\"event monitorColour{$slot['event']['MonitorId']}\"
+            style=\"left:{$left}%; width: {$width}%;\"
+  data-event-id=\"{$slot['event']['Id']}\" data-frame-id=\"".getSlotFrame($slot)."\"".
+  ( $mouseover ? ' data-on-mouseover-this="previewEvent" data-on-click-this="showEvent"' : ' data-on-click-this="previewEvent"').
+  '></div>';
+      unset( $slot );
     } # end if isset($currEventSlots[$i])
   } # end foreach width segment
+  unset ($currEventSlots);
 ?>
           </div>
 <?php
@@ -852,19 +796,19 @@ foreach( array_keys($monEventSlots) as $monitorId ) {
 ?>
         </div>
       </div>
-      <div id='chartLabels' class='graphWidth'>
-        <div id='key'>
+      <div id="chartLabels" class="graphWidth">
+        <div id="key">
 <?php
 foreach( array_keys($monEventSlots) as $monitorId ) {
 ?>
-          <span class='keyEntry'><?php echo $monitors[$monitorId]['Name'] ?>
-            <img id="keyBox<?php echo $monitorId ?>" class="keyBox monitorColour<?php echo $monitorId ?>" src="graphics/transparent.png" alt="<?php echo $monitors[$monitorId]['Name'] ?>"/>
+          <span class="keyEntry"><?php echo $monitors[$monitorId]->Name() ?>
+          <div id="keyBox<?php echo $monitorId ?>" class="keyBox monitorColour<?php echo $monitorId ?>" title="<?php echo $monitors[$monitorId]->Name() ?>" style="background-color: <?php echo $monitors[$monitorId]->WebColour() ?>;"></div>
           </span>
 <?php
 }
 ?>
         </div>
-        <div id='range'><?php echo $title ?></div>
+        <div id="range"><?php echo $title ?></div>
       </div>
     </div>
   </div>
